/*****************************************************************************/
/*                 data definitions for reflections plugins                  */
/*****************************************************************************/

/* title:    data definitions */
/* author:   Carsten Fuchs  */
/* version:  1.0, 16.9.97   */
/* updated:  10.3.98 by RG */
/*
   (c) 1998 und Vertrieb Oberland Computer
   In der Schneithohl 5
   61476 Kronberg
   Deutschland
   Tel.: 06173-608-0
   Fax:  06173-63385

   Support-Telefon: 06173-608-190
   Support-Fax:     06173-608-250
   Internet, WWW:   http://www.oberland.com
*/
/*****************************************************************************/

#ifndef BEAMSGATEW_D
#define BEAMSGATEW_D

/*****************************************************************************/

#include <fplug.h>

/*****************************************************************************/
/*         ID-numbers for RPI_message(PLI_param *in,PLI_param *out)          */
/*   these IDs are stored in in.id and used for case switch in RPI_message() */
/*****************************************************************************/

/* general messages **********************************************************/

#define PLI_CONNECT FPLUG_USER_MESSAGE+1
/* establish contact with reflections, time to setup resource */
#define PLI_CLOSE_RESOURCES FPLUG_USER_MESSAGE+2
/* plugin will be unloaded, time to cleanup resources */

/* proctext messages *********************************************************/

#define BMS_OFFSET FPLUG_USER_MESSAGE+1000000

#define PLI_BEAMS_PTEX_MATERIAL BMS_OFFSET
/* do color/transparency/reflection calculation and/or setup for bumping */
#define PLI_BEAMS_PTEX_BUMP BMS_OFFSET+1
/* do bumping calculations, always preceeded by PLI_BEAMS_PTEX_MATERIAL */
#define PLI_BEAMS_PTEX_BACKGROUND BMS_OFFSET+2
/* calculate color for background */
#define PLI_BEAMS_PTEX_INIT BMS_OFFSET+3
#define PLI_BEAMS_PTEX_END BMS_OFFSET+4

/*****************************************************************************/
/*                          RPI_do commands for beams                        */
/*****************************************************************************/

#define BMS_GET_LAST_PTEX_HIT BMS_OFFSET+10000
#define BMS_GET_LOKAL_PTEX_KOORD BMS_OFFSET+10001
#define BMS_MESSAGE_WIN BMS_OFFSET+11000

/*****************************************************************************/
/*                 error-codes as returned by RPI_get_last_err               */
/*****************************************************************************/

#define PLERR_NO_ERR 0
#define BMS_PLERR_UNKNOWN_COMMAND 1
#define BMS_PLERR_ILLEGAL_TEX_HANDLE  BMS_OFFSET+100000

/*****************************************************************************/
/* the following structure is used by reflections to manage a plugin. all */
/* values are !!read only!! for the plugin, except the user data entry, which
/* you can use to store a pointer to the plugin data */

typedef struct {  

   long  n_cols;            /* nr of colors */
   long  n_float_param;     /* nr of parameters */
   float *colors;           /* colors, stored as rgbrgbrgb... */
   float *param;            /* parameters */
   char  plugin_name[32];   /* the name of the plugin */
   int   intern_nr;         /* internal number 0,1,...(DLL <name> nr <internal_nr> )*/
   int   init_failed;       /* flag for the tracer. if its !=0, the initialization */
                            /* has failed, then the normal material is used */
   void *user_data;         /* user-data of the plugin */

} proctex_rec;

/*****************************************************************************/

#endif

/*****************************************************************************/
