/*****************************************************************************/
/*                   Reflections Plugin Support Functions                    */
/*****************************************************************************/

/* title:    modal & non modal requester functions */
/* author:   Reinhard Grams */
/* version:  1.0, 14.11.97 */
/* updated:  25.3.98 by RG */

/*****************************************************************************/

#include <NMReq_d.h>
#include <NMReq_f.h>

/*****************************************************************************/
/* call this if you altered vars of the running requester */

   void
UpdateNMRequester
   (long id,long nr_of_entries,long *codes,void **vars,void **tmp)
{
   long entry=0,var=0,cycles=0;
   
   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            strcpy((char *)(tmp[var]),(char *)(vars[var]));
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            *(long *)tmp[var]=*(long *)vars[var];
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            *(float *)tmp[var]=*(float *)vars[var];
            var++;
         break;

         case CODE_CYCLE:
            *(long *)tmp[var]=*((Cycle *)vars[var])->select;
            var++; entry++; cycles++;
         break;

         case CODE_TEXT:
            var++; 
         break;

         default: break;
      }
      entry++;
   }
   RPI_requester_values_changed(HND,id);
}

/*****************************************************************************/
/* get the edited variable of the requester, -1 means nothing changed */

   long
GetNMRequesterAlteredVariable
   (long nr_of_entries,long *codes,void **vars,void **tmp)
{
   long entry=0,var=0;

   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            if (strcmp((char *)(tmp[var]),(char *)(vars[var]))) {
               strcpy((char *)(tmp[var]),(char *)(vars[var]));
               return(var);
            }
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            if (*(long *)tmp[var] != *(long *)vars[var]) {
               *(long *)tmp[var] = *(long *)vars[var];
               return(var);
            }
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            if (*(float *)tmp[var] != *(float *)vars[var]) {
               *(float *)tmp[var] = *(float *)vars[var];
               return(var);
            }
            var++;
         break;

         case CODE_CYCLE:
            if (*(long *)tmp[var] != *((Cycle *)vars[var])->select) {
               *(long *)tmp[var] = *((Cycle *)vars[var])->select;
               return(var);
            }
            var++; entry++;
         break;

         case CODE_TEXT:
            var++;
         break;

         default: break;
      }
      entry++;
   }
   return(-1);
}

/*****************************************************************************/
/* user has canceled the requester, restore original values */

   void
CancelNMRequester
   (long nr_of_entries,long *codes,void **vars,void **org)
{
   long entry=0,var=0;

   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            strcpy((char *)(vars[var]),(char *)(org[var]));
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            *(long *)vars[var]=*(long *)org[var];
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            *(float *)vars[var]=*(float *)org[var];
            var++;
         break;

         case CODE_CYCLE:
            *((Cycle *)vars[var])->select=*(long *)org[var];
            var++; entry++;
         break;

         case CODE_TEXT:
            var++;
         break;

         default: break;
      }
      entry++;
   }
}

/*****************************************************************************/
/* create requester and setup the buffers */

   long
CreateNMRequesterXY
   (char *title,long id,long x_pos,long y_pos,long nr_of_entries,long *messages,long *codes,
   void **vars,void **tmp, void **org,char **names,float *minmax,long modal)
{
   long err=PLUG_OK;
   long entry=0,var=0,cycles=0;
   
   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            strcpy((char *)(org[var]),(char *)(vars[var]));
            strcpy((char *)(tmp[var]),(char *)(vars[var]));
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            *(long *)org[var]=*(long *)vars[var];
            *(long *)tmp[var]=*(long *)vars[var];
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            *(float *)org[var]=*(float *)vars[var];
            *(float *)tmp[var]=*(float *)vars[var];
            var++;
         break;

         case CODE_CYCLE:
            *(long *)org[var]=*((Cycle *)vars[var])->select;
            *(long *)tmp[var]=*((Cycle *)vars[var])->select;
            var++; entry++; cycles++;
         break;

         case CODE_TEXT:
            var++; 
         break;

         default: break;
      }
      entry++;
   }
   /* flag for requester setup phase */
   *messages=0;
   if (!RPI_define_requester(HND,title,id,x_pos,y_pos,
         nr_of_entries-cycles,modal,names,codes,vars,minmax)) {
      err=PLUG_OPEN_REQ_ERR; goto ErrorExit;
   }
   /* requester installed */
   *messages=1;

ErrorExit:
   return(err);
}

/*****************************************************************************/
