/*****************************************************************************/
/*                   Reflections Plugin Support Functions                    */
/*****************************************************************************/

/* title:    modal & non modal requester functions, handle passed as parm */
/* author:   Reinhard Grams */
/* version:  1.0, 14.11.97 */
/* updated:  10.3.98 by RG */
/*
   (c) 1998 und Vertrieb Oberland Computer
   In der Schneithohl 5
   61476 Kronberg
   Deutschland
   Tel.: 06173-608-0
   Fax:  06173-63385

   Support-Telefon: 06173-608-190
   Support-Fax:     06173-608-250
   Internet, WWW:   http://www.oberland.com
*/
/*****************************************************************************/

#include <NMReq_d.h>
#include <NMReq2_f.h>

/*****************************************************************************/
/* call this if you altered vars of the running requester */

   void
UpdateNMRequester
   (RPI_HANDLE handle,long id,long nr_of_entries,long *codes,void **vars,void **tmp)
{
   long entry=0,var=0,cycles=0;
   
   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            strcpy((char *)(tmp[var]),(char *)(vars[var]));
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            *(long *)tmp[var]=*(long *)vars[var];
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            *(float *)tmp[var]=*(float *)vars[var];
            var++;
         break;

         case CODE_CYCLE:
            *(long *)tmp[var]=*((Cycle *)vars[var])->select;
            var++; entry++; cycles++;
         break;

         case CODE_TEXT:
            var++; 
         break;

         default: break;
      }
      entry++;
   }
   RPI_requester_values_changed(handle,id);
}

/*****************************************************************************/
/* get the edited variable of the requester, -1 means nothing changed */

   long
GetNMRequesterAlteredVariable
   (long nr_of_entries,long *codes,void **vars,void **tmp)
{
   long entry=0,var=0;

   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            if (strcmp((char*)tmp[var],(char*)vars[var])) {
               strcpy((char*)tmp[var],(char*)vars[var]);
               return(var);
            }
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            if (*(long *)tmp[var] != *(long *)vars[var]) {
               *(long *)tmp[var] = *(long *)vars[var];
               return(var);
            }
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            if (*(float *)tmp[var] != *(float *)vars[var]) {
               *(float *)tmp[var] = *(float *)vars[var];
               return(var);
            }
            var++;
         break;

         case CODE_CYCLE:
            if (*(long *)tmp[var] != *((Cycle *)vars[var])->select) {
               *(long *)tmp[var] = *((Cycle *)vars[var])->select;
               return(var);
            }
            var++; entry++;
         break;

         case CODE_TEXT:
            var++;
         break;

         default: break;
      }
      entry++;
   }
   return(-1);
}

/*****************************************************************************/
/* user has canceled the requester, restore original values */

   void
CancelNMRequester
   (long nr_of_entries,long *codes,void **vars,void **org)
{
   long entry=0,var=0;

   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            strcpy((char*)vars[var],(char*)org[var]);
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            *(long *)vars[var]=*(long *)org[var];
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            *(float *)vars[var]=*(float *)org[var];
            var++;
         break;

         case CODE_CYCLE:
            *((Cycle *)vars[var])->select=*(long *)org[var];
            var++; entry++;
         break;

         case CODE_TEXT:
            var++;
         break;

         default: break;
      }
      entry++;
   }
}

/*****************************************************************************/
/* create requester and set up the buffers */

   long
CreateNMRequester
   (RPI_HANDLE handle,char *title,long id,long nr_of_entries,long *messages,long *codes,
   void **vars,void **tmp, void **org,char **names,float *minmax,long modal)
{
   long err=PLUG_OK;
   long entry=0,var=0,cycles=0;
   
   while (entry<nr_of_entries) {

      switch (codes[entry]) {

         case CODE_STRING:
            strcpy((char*)org[var],(char*)vars[var]);
            strcpy((char*)tmp[var],(char*)vars[var]);
            var++;
         break;

         case CODE_INT:
         case CODE_INT_EXTENDED:
            *(long *)org[var]=*(long *)vars[var];
            *(long *)tmp[var]=*(long *)vars[var];
            var++;
         break;

         case CODE_REAL:
         case CODE_REAL_EXTENDED:
            *(float *)org[var]=*(float *)vars[var];
            *(float *)tmp[var]=*(float *)vars[var];
            var++;
         break;

         case CODE_CYCLE:
            *(long *)org[var]=*((Cycle *)vars[var])->select;
            *(long *)tmp[var]=*((Cycle *)vars[var])->select;
            var++; entry++; cycles++;
         break;

         case CODE_TEXT:
            var++; 
         break;

         default: break;
      }
      entry++;
   }
   /* flag for requester setup phase */
   *messages=0;
   if (!RPI_define_requester(handle,title,id,-1,-1,
         nr_of_entries-cycles,modal,names,codes,vars,minmax)) {
      err=PLUG_OPEN_REQ_ERR; goto ErrorExit;
   }
   /* requester installed */
   *messages=1;

ErrorExit:
   return(err);
}

/*****************************************************************************/
