/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    after-burner functions */
/* author:   Carsten Fuchs  */
/* version:  1.0, 30.6.99   */
/* updated:  16.11.99 by RG */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
#if MONZOOM_VERSION >= 45
/*****************************************************************************/
/*  allocate a new after-burner */

   RPIStub long
RPI_new_afterburner
   (RPI_HANDLE handle,char *name,long *id_nr);

   /* handle:      refgateway-handle
      id_nr:       destination for afterburner-id
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/*  delete an allocated after-burner */

   RPIStub long
RPI_del_afterburner
   (RPI_HANDLE handle,long id_nr);

   /* handle:      refgateway-handle
      id_nr:       afterburner-id
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/*  allocate a channel for an object */

   RPIStub long
RPI_afterburner_get_obj_kanal
   (RPI_HANDLE handle,long ab_id,RPI_OBJECT obj,long *id_nr);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      obj:         monzoom-object-handle
      id_nr:       destination for the id of the channel
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/*  release the channel-number for an object */

   RPIStub long
RPI_afterburner_release_obj_kanal
   (RPI_HANDLE handle,long ab_id,RPI_OBJECT obj);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      obj:         monzoom-object-handle
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get a map of all pixels, in which then kanal_id happens */

   RPIStub long
RPI_afterburner_get_kanal_map
   (RPI_HANDLE handle,long ab_id,long win_id,long kanal_id,unsigned char **map,long *npix);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      win_id:      number of the display
      kanal_id:    channel_id
      map:         destination for pointer to channel_map
      npix:        destination for the number of pixels set in the channel_map
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* this afterburner wants dephtbuffer-data  */

   RPIStub long
RPI_afterburner_alloc_depthbuff
   (RPI_HANDLE handle,long ab_id);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* this after-burner dont want the dephtbuffer-data any more */

   RPIStub long
RPI_afterburner_free_depthbuff
   (RPI_HANDLE handle,long ab_id);

   /* handle:      refgateway-handle
      ab_id:       id-nr of afterburner
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the depth-value of a pixel */

   RPIStub long
RPI_afterburner_get_pixel_depth
   (RPI_HANDLE handle,long ab_id,long win_id,long x,long y,float *depth);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      win_id:      number of the display
      x,y:         pixel-coordinates
      depth:       destination for depth-value of pixel
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the depth-value of a set of pixels */

   RPIStub long
RPI_afterburner_get_multi_pixel_depth
   (RPI_HANDLE handle,long ab_id,long win_id,long npts,long *xy,float *depth);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      win_id:      number of the display
      npix:        number of pixels
      xy:          array with pixel-coordinates
      depth:       destination for depth-values of pixels
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the depth-values for a rectangle of pixels */

   RPIStub long
RPI_afterburner_get_pixel_rect_depth
   (RPI_HANDLE handle,long ab_id,long win_id,long x1,long y1,long x2,long y2,float *depth);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      win_id:      number of the display
      x1,y1,x2,y2: pixel-coordinates of rectangle
      depth:       destination for depth-values of pixels
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the depth-value of a background-pixel */

   RPIStub long
RPI_afterburner_get_background_depth
   (RPI_HANDLE handle,long ab_id,float *depth);

   /* handle:      refgateway-handle
      ab_id:       id of the afterburner
      depth:       destination for depth-value of pixel
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
#endif /* if MONZOOM_VERSION >= 45 */
/*****************************************************************************/
