/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/

/* title:    animfx functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  3.10.98 by RG */
/* updated:  29.12.97 by RG */
/* updated:  16.11.99 by RG */
/* updated:  2.3.2000 by RG */

/*****************************************************************************/
/* allocate internal variables of an afx-object */

   RPIStub long
RPI_afx_alloc_intern_vars
   (RPI_HANDLE handle,void *afx,long n_int,long n_real,long n_obj)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      n_real:      number of real (float) variables
      n_int:       number of integer variables
      n_obj:       number of object handles
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_ALLOK_INTERN_VARS;
   in.l_param[0]=n_real;
   in.l_param[1]=n_int;
   in.l_param[2]=n_obj;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* set internal integer variable of an afx-object */

   RPIStub long
RPI_afx_set_int
   (RPI_HANDLE handle,void *afx,long nr,long wert)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of integer var (0..n_int-1)
      wert:        integer value to set
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_SET_INT;
   in.l_param[0]=nr;
   in.l_param[1]=wert;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get internal integer variable of an afx-object */

   RPIStub long
RPI_afx_get_int
   (RPI_HANDLE handle,void *afx,long nr,long *wert)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of integer var (0..n_int-1)
      wert:        destination of integer value
      returns:     0 if failed
   */
   PLI_param in,out;
   long ret;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_GET_INT;
   in.l_param[0]=nr;
   if ((ret=RPI_do(&in,&out))!=0) {
      *wert=out.l_param[0];
   }
   return(ret);
}
/*****************************************************************************/
/* set internal real variable of an afx-object */

   RPIStub long
RPI_afx_set_real
   (RPI_HANDLE handle,void *afx,long nr,float wert)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of real var (0..n_real-1)
      wert:        real-value to set
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_SET_REAL;
   in.l_param[0]=nr;
   in.f_param[0]=wert;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get internal real variable of an afx-object */

   RPIStub long
RPI_afx_get_real
   (RPI_HANDLE handle,void *afx,long nr,float *wert)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of real var (0..n_real-1)
      wert:        destination of real value
      returns:     0 if failed
   */
   PLI_param in,out;
   long ret;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_GET_REAL;
   in.l_param[0]=nr;
   if ((ret=RPI_do(&in,&out))!=0) {
      *wert=out.f_param[0];
   }
   return(ret);
}
/*****************************************************************************/
/* set internal object handle of an afx-object */

   RPIStub long
RPI_afx_set_obj
   (RPI_HANDLE handle,void *afx,long nr,RPI_OBJECT obj)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of real var (0..n_obj-1)
      obj:         object handle
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_SET_OBJ;
   in.l_param[0]=nr;
   in.v_param[2]=obj;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get internal object handle of an afx-object */

   RPIStub long
RPI_afx_get_obj
   (RPI_HANDLE handle,void *afx,long nr,RPI_OBJECT *wert)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of handle (0..n_obj-1)
      obj:         destination of object handle
      returns:     0 if failed
   */
   PLI_param in,out;
   long ret;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_GET_OBJ;
   in.l_param[0]=nr;
   if ((ret=RPI_do(&in,&out))!=0) {
      *wert=out.v_param[0];
   }
   return(ret);
}
/*****************************************************************************/
/* set nr of object-variables of an afx-object */

   RPIStub long
RPI_afx_set_n_obj_vars
   (RPI_HANDLE handle,void *afx,long nvars)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nvars:       nr of object-variables
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_SET_N_OBJ_VARS;
   in.l_param[0]=nvars;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* define an object-variable of an afx-object */

   RPIStub long
RPI_afx_define_obj_var
   (RPI_HANDLE handle,void *afx,long nr,long art,char *name,float min,float max)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of var (0..n_vars-1)
      art:         kind of variable: 0=integer 1=real
      name:        name of variable
      min,max:     minimum and maximum values for slider
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_DEFINE_OBJ_VAR;
   in.l_param[0]=nr;
   in.l_param[1]=art;
   in.s_param[0]=name;
   in.f_param[0]=min;
   in.f_param[1]=max;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* define an rgb-variable of an afx-object. this includes 3 variables
  (red,green,blue). the number of real vars has to be set properly!
*/

   RPIStub long
RPI_afx_define_obj_rgb_var
   (RPI_HANDLE handle,void *afx,long nr)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      nr:          index of first variable
                   red=var <nr>, green=var <nr>+1, blue=var <nr+2>
      returns:     0 if failed
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_DEFINE_OBJ_RGB_VAR;
   in.l_param[0]=nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* store a pointer for specific user-data in an animfx-object*/

   RPIStub long
RPI_afx_set_user_data
   (RPI_HANDLE handle,void *afx,void *user_data)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      user_data:   ptr to user_data
      returns:     NULL if failed
                   
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_SET_USER_DATA;
   in.v_param[2]=user_data;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get a pointer for specific user-data in an animfx-object*/

   RPIStub long
RPI_afx_get_user_data
   (RPI_HANDLE handle,void *afx,void **user_data)
{
   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj 
      user_data:   destination for ptr to user_data
      returns:     NULL if failed
   */
   PLI_param in,out;
   long ret;
   
   in.v_param[0]=handle;
   in.v_param[1]=afx;
   in.id=RPI_AFX_GET_USER_DATA;
   if ((ret=RPI_do(&in,&out))!=0) {
      *user_data=out.v_param[0];
   }
   return(ret);
}
/*****************************************************************************/
