/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    animfx functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  3.10.98 by RG */
/* updated:  29.12.97 by RG */
/* updated:  16.11.99 by RG */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
/* allocate internal variables of an afx-object */

   RPIStub long
RPI_afx_alloc_intern_vars
   (RPI_HANDLE handle,void *afx,long n_int,long n_real,long n_obj);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      n_real:      number of real (float) variables
      n_int:       number of integer variables
      n_obj:       number of object handles
      returns:     0 if failed
   */
/*****************************************************************************/
/* set internal integer variable of an afx-object */

   RPIStub long
RPI_afx_set_int
   (RPI_HANDLE handle,void *afx,long nr,long wert);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of integer var (0..n_int-1)
      wert:        integer value to set
      returns:     0 if failed
   */
/*****************************************************************************/
/* get internal integer variable of an afx-object */

   RPIStub long
RPI_afx_get_int
   (RPI_HANDLE handle,void *afx,long nr,long *wert);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of integer var (0..n_int-1)
      wert:        destination of integer value
      returns:     0 if failed
   */
/*****************************************************************************/
/* set internal real variable of an afx-object */

   RPIStub long
RPI_afx_set_real
   (RPI_HANDLE handle,void *afx,long nr,float wert);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of real var (0..n_real-1)
      wert:        real-value to set
      returns:     0 if failed
   */
/*****************************************************************************/
/* get internal real variable of an afx-object */

   RPIStub long
RPI_afx_get_real
   (RPI_HANDLE handle,void *afx,long nr,float *wert);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of real var (0..n_real-1)
      wert:        destination of real value
      returns:     0 if failed
   */
/*****************************************************************************/
/* set internal object handle of an afx-object */

   RPIStub long
RPI_afx_set_obj
   (RPI_HANDLE handle,void *afx,long nr,RPI_OBJECT obj);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of real var (0..n_obj-1)
      obj:         object handle
      returns:     0 if failed
   */
/*****************************************************************************/
/* get internal object handle of an afx-object */

   RPIStub long
RPI_afx_get_obj
   (RPI_HANDLE handle,void *afx,long nr,RPI_OBJECT *wert);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of handle (0..n_obj-1)
      obj:         destination of object handle
      returns:     0 if failed
   */
/*****************************************************************************/
/* set nr of object-variables of an afx-object */

   RPIStub long
RPI_afx_set_n_obj_vars
   (RPI_HANDLE handle,void *afx,long nvars);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nvars:       nr of object-variables
      returns:     0 if failed
   */
/*****************************************************************************/
/* define an object-variable of an afx-object */

   RPIStub long
RPI_afx_define_obj_var
   (RPI_HANDLE handle,void *afx,long nr,long art,char *name,float min,float max);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of var (0..n_vars-1)
      art:         kind of variable: 0=integer 1=real
      name:        name of variable
      min,max:     minimum and maximum values for slider
      returns:     0 if failed
   */
/*****************************************************************************/
/* define an rgb-variable of an afx-object. this includes 3 variables
  (red,green,blue). the number of real vars has to be set properly!
*/

   RPIStub long
RPI_afx_define_obj_rgb_var
   (RPI_HANDLE handle,void *afx,long nr);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      nr:          index of first variable
                   red=var <nr>, green=var <nr>+1, blue=var <nr+2>
      returns:     0 if failed
   */
/*****************************************************************************/
/* store a pointer for specific user-data in an animfx-object*/

   RPIStub long
RPI_afx_set_user_data
   (RPI_HANDLE handle,void *afx,void *user_data);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      user_data:   ptr to user_data
      returns:     NULL if failed
   */
/*****************************************************************************/
/* get a pointer for specific user-data in an animfx-object*/

   RPIStub long
RPI_afx_get_user_data
   (RPI_HANDLE handle,void *afx,void **user_data);

   /* handle:      refgateway-handle
      afx:         ptr to animfx-obj
      user_data:   destination for ptr to user_data
      returns:     NULL if failed
   */
/*****************************************************************************/
