/*****************************************************************************/
/*                    definitions for reflections gateway                    */
/*****************************************************************************/

/* title:    refgateway definitions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* version:  1.1, 15.9.98 */
/* updated:  17.9.98 */
/* version:  1.2, 8.10.98 */
/* updated:  9.10.98 by RG */
/* updated:  25.11.98 */
/* version:  1.3, 3.3.99 */
/* updated:  25.8.99 */
/* updated:  6.9.99 */
/* updated:  22.10.99 */
/* updated:  17.11.99 by RG */
/* updated:  8.12.99 by RG */
/* updated:  14.1.2000 by RG */
/* updated:  2.3.2000 by CF */

/*****************************************************************************/

#ifndef REFGATEW_D
#define REFGATEW_D

/*****************************************************************************/

#include <fplug.h>

/*****************************************************************************/
/*         ID-numbers for RPI_message(PLI_param *in,PLI_param *out)          */
/*   these IDs are stored in in.id and used for case switch in RPI_message() */
/*****************************************************************************/

/* general messages **********************************************************/

#define PLI_CONNECT FPLUG_USER_MESSAGE+1
/* establish contact with reflections, time to setup resource */
#define PLI_CLOSE_RESOURCES FPLUG_USER_MESSAGE+2
/* plugin will be unloaded, time to cleanup resources */

#define PLI_TIMER FPLUG_USER_MESSAGE+3
/* timer-event*/

#define PLI_BUTTON_WIN_PRESSED FPLUG_USER_MESSAGE+9
/* in a button window a button has been pressed:
   l_param[0] = number of the button window
   l_param[1] = number of the button
*/
#define PLI_BUTTON_WIN_RELEASED FPLUG_USER_MESSAGE+10
/* in a button window a button has been released:
   l_param[0] = number of the button window
   l_param[1] = number of the button
*/
#define PLI_BUTTON_WIN_CLOSED FPLUG_USER_MESSAGE+11
/*  the button window has been closed:
   l_param[0] = number of the button window
   l_param[1] = last x-pos of window
   l_param[2] = last y-pos of window
*/
#define PLI_OBJ_EVENT FPLUG_USER_MESSAGE+12
/* an event has happened 
   l_param[0] = ID of the event, see INFORM_.. defines below
   v_param[0] = object that was source of the event
*/
#define INFORM_OBJ_DEL           0x00000001
#define INFORM_OBJ_SUB_PKL       0x00000002
#define INFORM_OBJ_ADD_PKL       0x00000004
#define INFORM_OBJ_MOVED         0x00000008
#define INFORM_OBJ_PTS_MOVED     0x00000010
#define INFORM_OBJ_PTS_CHANGED   0x00000020
#define INFORM_OBJ_MAT_CHANGED   0x00000040
#define INFORM_ALL\
   (INFORM_OBJ_DEL|INFORM_OBJ_SUB_PKL|INFORM_OBJ_ADD_PKL\
   |INFORM_OBJ_MOVED|INFORM_OBJ_PTS_MOVED|INFORM_OBJ_PTS_CHANGED\
   |INFORM_OBJ_MAT_CHANGED)

/* GEO_EDIT events ***********************************************************/

#define PLI_GEO_EDIT_EVENT FPLUG_USER_MESSAGE+13
/*   l_param[0] = ID of GEO_EDIT event  
     v_param[0] = selected geo-obj or NULL
*/
#define INFORM_START_GEO_EDIT 1
/* geo-edit started: if v_param[0]==0 then geo_edit started with no obj */
#define INFORM_CLOSE_GEO_EDIT 2
#define INFORM_START_GEO_PT_EDIT 4
#define INFORM_CLOSE_GEO_PT_EDIT 8

#define PLI_GEO_EDIT_TOOL FPLUG_USER_MESSAGE+14
#define PLI_GEO_EDIT_TOOL_INFO FPLUG_USER_MESSAGE+15
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_PRESSED FPLUG_USER_MESSAGE+16
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_RELEASED FPLUG_USER_MESSAGE+17
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_LMOUSE_DOWN FPLUG_USER_MESSAGE+18
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_LMOUSE_UP FPLUG_USER_MESSAGE+19
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_LMOUSE_MOVE FPLUG_USER_MESSAGE+20
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_CANCEL FPLUG_USER_MESSAGE+21
#define PLI_GEO_EDIT_INTERACTIVE_TOOL_CLOSE FPLUG_USER_MESSAGE+22

/* operations messages *******************************************************/

#define PLI_CHECK_SINGLE_TOOL FPLUG_USER_MESSAGE+1000
/*
   in->l_param[0]  = single_tool id
   in->v_param[0]  = object
   the plugin returns:
   out->l_param[0] = 0: if check failed
                     1: if object is ok
*/
#define PLI_DO_SINGLE_TOOL FPLUG_USER_MESSAGE+1001
/*
   in->l_param[0] = single_tool id
   in->v_param[0] = object
*/

/* loader messages ***********************************************************/

#define PLI_LOAD_SCENE FPLUG_USER_MESSAGE+1002
/*
   in->s_param[0]  = filename of scene
   in->s_param[1]  = buffer for error message in case 2
   the plugin returns:
   out->l_param[0] = 1: processed without error
                     0: unknown format
                     2: format known, but error happens while reading
                        copy error-string to in.s_param[0]!
*/

/* saver messages ************************************************************/

#define PLI_SAVE_SCENE FPLUG_USER_MESSAGE+1016
/*
   in->s_param[0] = filename of scene
   in->s_param[1] = buffer for error message in case 2
   in->l_param[0] = scene-type, which the user has selected
                    ( one of the types, which this plugin-supports)
   in->l_param[1] = number of objects to save <n_obj>
   in->v_param[0] = a pointer to an array of <n_obj> handles to objects

   the plugin returns:
   out->l_param[0] = 1: processed without error
                     0: error happens while writing
                        copy error-string to in.s_param[0]!
*/

/* touch message **************************************************************/

#define PLI_TOUCH FPLUG_USER_MESSAGE+1003
/* message is sended when user invoked the menu entry a second time */

/* create tool messages *******************************************************/

#define PLI_DO_CREATE_TOOL FPLUG_USER_MESSAGE+1004
/* message is sended when user invoked the create_tool in create-popupmenu entry */

/* RGB_PIC_MESSAGE ***********************************************************/

#define PLI_RGB_INIT_READ FPLUG_USER_MESSAGE+1010
/*

   in->s_param[0]  = filename of rgb-file
   in->s_param[1]  = buffer for error message in case 2
   the plugin returns:
   out->l_param[0] = 1: processed without error
                     0: unknown format
                     2: format known, error happens while reading
                        copy error-string to in.s_param[1]!
   out->l_param[1] = dx-pixel
   out->l_param[2] = dy-pixel

  plugin may open the file and keep it opened.
  it is garanteed that for every INIT_READ-message follows a 
  CLOSE_READ-message where the plugin has to close the file
*/

#define PLI_RGB_CLOSE_READ FPLUG_USER_MESSAGE+1011
#define PLI_RGB_READ_ROW FPLUG_USER_MESSAGE+1012
/*
   plugin has to copy the next row of the picture (separated for red,green,blue)
   into three arrays.
   in->s_param[0]  = buffer for error message in case of error
   in->v_param[0]  = destination for red-row
   in->v_param[1]  = destination for green-row
   in->v_param[2]  = destination for blue-row

   the plugin returns:
   out->l_param[0] = 1: processed without error
                     0: error happened during decompression

*/

#define PLI_RGB_INIT_WRITE FPLUG_USER_MESSAGE+1013
/*
   in->s_param[0]  = filename of rgb-file
   in->s_param[1]  = buffer for error message in case of error
   in->l_param[0]  = dx-pixel
   in->l_param[1]  = dy-pixel
   in->l_param[2]  = nr of type (0..n_types-1; n_types = nr of types this plugin supports)
   the plugin returns:
   out->l_param[0] = 1: processed without error
                     0: unknown format
                     
   plugin may open the file and keep it opened.
   it is garanteed that for every INIT_WRITE-message follows a 
   CLOSE_WRITE-message where the plugin has to  close the file
*/

#define PLI_RGB_CLOSE_WRITE FPLUG_USER_MESSAGE+1014
#define PLI_RGB_WRITE_ROW FPLUG_USER_MESSAGE+1015
/*
   plugin has to write the next row of the picture (separated for red,green,blue)
   from three arrays to the file
   in->s_param[0] = buffer for error message in case of error
   in->v_param[0] = source for red-row
   in->v_param[1] = source for green-row
   in->v_param[2] = source for blue-row

   the plugin returns:
   out->l_param[0] = 1: processed without error
                     0: error happened during compression
*/

/* sys tool messages **********************************************************/

#define PLI_DO_SYS_COMMAND FPLUG_USER_MESSAGE+1050
/* messages is sended when user selected the sys_tool */
/*
   in->l_param[0] = id of command
*/

/* version messages ************************************************************/

#define PLI_GET_VERSION FPLUG_USER_MESSAGE+1051
/* message is sended to request plugin version and revision */
/*
   out->l_param[0] = version of plugin
   out->l_param[1] = revision of plugin
*/

/* non-modal requester messages ***********************************************/

/* messages sended for non-modal-requesters */
#define PLI_NM_REQUESTER_CHANGED FPLUG_USER_MESSAGE+1100
#define PLI_NM_REQUESTER_OK FPLUG_USER_MESSAGE+1101
#define PLI_NM_REQUESTER_CANCEL FPLUG_USER_MESSAGE+1102

/* messages sended for plugin-save/load data *********************************/
#define PLI_DATA_SAVE FPLUG_USER_MESSAGE+1110
/* out->l_param[0]  nr of bytes to save
   out->v_param[0]  pointer to buffer with the data to be saved   
*/

#define PLI_DATA_LOAD FPLUG_USER_MESSAGE+1111
/* out->l_param[0]  nr of bytes to load
   out->v_param[0]  pointer to buffer with the data to be loaded
*/

/* messages for afx plugins **************************************************/
#define PLI_AFX                        FPLUG_USER_MESSAGE+10000
#define PLI_AFX_INIT                   FPLUG_USER_MESSAGE+10001
#define PLI_AFX_INIT_READ              FPLUG_USER_MESSAGE+10002
#define PLI_AFX_START                  FPLUG_USER_MESSAGE+10003
#define PLI_AFX_PRE_RENDER             FPLUG_USER_MESSAGE+10004
#define PLI_AFX_AFTER_RENDER           FPLUG_USER_MESSAGE+10005
#define PLI_AFX_FINISH                 FPLUG_USER_MESSAGE+10006
#define PLI_AFX_GET_OBJS               FPLUG_USER_MESSAGE+10007
#define PLI_AFX_SET_OBJS               FPLUG_USER_MESSAGE+10008
#define PLI_AFX_GET_INFO               FPLUG_USER_MESSAGE+10009
#define PLI_AFX_SHOW_EDIT_WIN          FPLUG_USER_MESSAGE+100010
#define PLI_AFX_OBJ_VARS_CHANGED       FPLUG_USER_MESSAGE+100011

/* messages for after-burners ************************************************/
#define PLI_AFTER_BURNER_PRERENDER FPLUG_USER_MESSAGE+10100
#define PLI_AFTER_BURNER_AFTERRENDER FPLUG_USER_MESSAGE+10101
/* in->l_param[0]   afterburner_id
   in->l_param[1]   display_id
   in->l_param[2]   flags
*/
#define PLI_AFTER_BURNER_DISPLAY_INVALID FPLUG_USER_MESSAGE+10102
/* in->l_param[0]   afterburner_id
   in->l_param[1]   display_id
*/
/* flags for afterrender-message */
#define AFTER_BURNER_FLAG_IS_ANIM_DISPLAY 0x00000001
#define AFTER_BURNER_FLAG_IS_EDIT_DISPLAY 0x00000002
/* values for channel maps */
#define AFTER_BURNER_PIXEL_IS_UNUSED    0
#define AFTER_BURNER_PIXEL_IS_USED      1

/* messages for custom_data-load_saves ***************************************/
#define PLI_CUSTOM_DATA_LOAD FPLUG_USER_MESSAGE+10200
#define PLI_CUSTOM_DATA_SAVE FPLUG_USER_MESSAGE+10201
#define PLI_CUSTOM_DATA_SAVE_FERTIG FPLUG_USER_MESSAGE+10202

/* create_obj messages *******************************************************/
#define CREATE_OBJ_START  0
#define CREATE_OBJ_CHANGE 1
#define CREATE_OBJ_FINISH 2
#define CREATE_OBJ_LOADED 3

#define PLI_DO_BUILD_OBJ FPLUG_USER_MESSAGE+10300
#define PLI_DO_SAVE_BUILD_DATA FPLUG_USER_MESSAGE+10301
#define PLI_DO_SAVE_BUILD_DATA_READY FPLUG_USER_MESSAGE+10302
#define PLI_DO_LOAD_BUILD_DATA FPLUG_USER_MESSAGE+10303

/* config data load/save *****************************************************/
#define PLI_CONFIG_DATA_SAVE FPLUG_USER_MESSAGE+10350
/* out->l_param[0]  nr of bytes to save
   out->v_param[0]  pointer to buffer with the data to save
*/

#define PLI_CONFIG_DATA_LOAD FPLUG_USER_MESSAGE+10351
/* out->l_param[0]  nr of bytes to be loaded
   out->v_param[0]  pointer to buffer with the data to be loaded
   out->s_param[0]  name of plugin which owns the data
*/

/* messages for displays *****************************************************/
#define PLI_DISP_CLOSED FPLUG_USER_MESSAGE+10400
/* in->l_param[0]   display_id
   in->l_param[1]   x coord of window
   in->l_param[2]   y coord of window
*/
#define PLI_DISP_RESIZED FPLUG_USER_MESSAGE+10401
/* in->l_param[0]   display_id */
#define PLI_DISP_KEY_PRESSED FPLUG_USER_MESSAGE+10402
/* in->l_param[0]   display_id
   in->l_param[1]   key chr
   in->l_param[2]   x mouse coord
   in->l_param[3]   y mouse coord
*/
#define PLI_DISP_MOUSE_EVENT FPLUG_USER_MESSAGE+10403
/* in->l_param[0]   display_id
   in->l_param[1]   code
   in->l_param[2]   button
   in->l_param[3]   x mouse coord
   in->l_param[4]   y mouse coord
*/
/* parameter code */
#define PLI_MOUSE_PRESSED 1
#define PLI_MOUSE_RELEASED 2
#define PLI_MOUSE_MOVED 3
/* parameter button */
#define PLI_MOUSE_LEFT 1
#define PLI_MOUSE_RIGHT 2

/*****************************************************************************/
/*          IDs to request information from Ref4 with RPI_get_ref_info       */
/*****************************************************************************/

#define DISP_DEPTH 1
/* bit-depth of the display reflections is running on */
#define DISP_DX 2
#define DISP_DY 3
/* display size */
#define VERSION 4
#define RELEASE 5
#define REVISION 6
#define LANGUAGE 7
/* version-numbers */

/*****************************************************************************/
/*       IDs to request information from Ref4 with RPI_get_ref_char_info     */
/*****************************************************************************/

/* the current working directory of reflections */
#define REF_DIR 1
/* current temp-dir for reflections */
#define REF_TEMP_DIR 2
/* plugin-dir */
#define REF_PLUG_DIR 3
/* plugin-datadir */
#define REF_PLUG_DATA_DIR 4
/* help-dir */
#define REF_HELP_DIR 5
/* scenes-dir */
#define REF_SCENE_DIR 6
/* images-dir */
#define REF_PIC_DIR 7
/* animations-dir */
#define REF_ANIM_DIR 8
/* scripts-dir */
#define REF_SKRIPT_DIR 9
/*fonts-dir */
#define REF_FONT_DIR 10
/*materials-dir */
#define REF_MAT_DIR 11

/*****************************************************************************/
/*                 error-codes as returned by RPI_get_last_err               */
/*****************************************************************************/

/* general errors */
#define PLERR_NO_ERR 0
#define PLERR_ILLEGAL_PLUGIN 1
#define PLERR_ILLEGAL_BUTTON_WIN 3
#define PLERR_TIMER_ALREADY_ON 4 
#define PLERR_NO_TIMER 5  
#define PLERR_NO_MEM 6
#define PLERR_OBJ_CREATE_FAILED 8
#define PLERR_ILLEGAL_CHAR_INFO_ID 9
#define PLERR_ILLEGAL_INFO_ID 10
#define PLERR_NOT_ALLOWED 13
#define PLERR_UNKNOWN_COMMAND 14
#define PLERR_ILLEGAL_WIN_BUTTON 15
#define PLERR_PROZENT_ALREADY_ON 16
#define PLERR_NO_PROZENT 17

/* internal error */
#define PLERR_ERROR 16

/* non-modal_requester_error */
#define PLERR_ILLEGAL_NOMODAL 20

/* object errors */
#define PLERR_ILLEGAL_OBJ 1000
#define PLERR_ILLEGAL_OBJ_ID 1001
#define PLERR_NO_DREI_OBJ 1005
#define PLERR_DREI_ILLEGAL_DREI_NR 1006
#define PLERR_NO_MAT_OBJ 1007
#define PLERR_NO_SURF_OBJ 1008
#define PLERR_NO_POL2D_OBJ 1009
#define PLERR_TRIANG_FAILED 1010
#define PLERR_NO_PARTIKEL_OBJ 1011
#define PLERR_NO_MILL_PTS 1012
#define PLERR_NO_TEXM_OBJ 1013
#define PLERR_NO_AFX_OBJ 1014
#define PLERR_NO_KUG_OBJ 1015
#define PLERR_ILLEGAL_KUG_NR 1016
#define PLERR_NO_KANTEN_GEO_OBJ 1017
#define PLERR_NO_POL_OBJ 1018
#define PLERR_NO_KAM_OBJ 1019

/* geo-object errors */
#define PLERR_NO_GEO_OBJ 2000
#define PLERR_GEO_ILLEGAL_PT_NR 2001
#define PLERR_GEO_NOT_ON_DISPLAY 2002
#define PLERR_GEO_PT_NOT_PROJECTED 2003
#define PLERR_GEO_NO_PT_FOUND 2004
#define PLERR_GEO_ILLEGAL_SON 2005

/* geo-edit errors */
#define PLERR_GEO_EDIT_TOOL_ILLEGAL_RGB_FORMAT 2100
#define PLERR_GEO_EDIT_ILLEGAL_TOOL_ID 2101
#define PLERR_GEO_EDIT_CANT_PRESS_RELEASE_XTRA_BUTTON 2102

/* display-manager errors */
#define PLERR_DISPMAN_ILLEGAL_DISPLAY 3000

/* file-operations errors */
#define PLERR_NO_FILE 4000
#define PLERR_CANT_OPEN_FILE 4001
#define PLERR_ILLEGAL_FILE_HANDLE 4002
#define PLERR_FILE_WRITE_ERR 4003
#define PLERR_FILE_READ_ERR 4004
#define PLERR_ILLEGAL_FILE_MODE 4005
#define PLERR_FILE_FGETS_FAILED 4006
#define PLERR_FILE_FPUTS_FAILED 4007
#define PLERR_END_OF_FILE 4008

/* operations errors */
#define PLERR_ILLEGAL_TOOL_ID 5000

/* particle-object errors */
#define PLERR_PART_PARAMS_ALREADY_DEFINED 6000
#define PLERR_PART_NOT_MORE_THAN_32_PARAMS 6001
#define PLERR_PART_ILLEGAL_DATA_NR 6002

/* dreieck errors */
#define PLERR_NO_MILL_DREI 7000
#define PLERR_ILLEGAL_KOERPER_NR 7001
#define PLERR_DONT_DELETE_ALL_KOERPER 7002
#define PLERR_NO_UV_MAPPING_MODE 7003

/* heap errors */
#define PLERR_ILLEGAL_HEAP 7500

/* kant_geo errors */
#define PLERR_KANTEN_GEO_ILLEGAL_KANT_NR 8000
#define PLERR_KANTEN_GEO_ILLEGAL_PT_NR 8001

/* pkl errors */
#define PLERR_WRONG_DISPLAY_KONFIGURATION 8100
#define PLERR_OBJ_NOT_IN_PKL 8101

/* plugin data-save/load errors */
#define PLERR_SAVE_NOT_ALLOWED 8200
#define PLERR_LOAD_NOT_ALLOWED 8201

/* ERRORS for rpi_plot_triangles  */
#define PLERR_IS_NO_WIRE_DISPLAY 8300

/* ERRORS for plugin_custom-datas  */
#define PLERR_CUSTOM_ID_ALREADY_DEFINED 9000
#define PLERR_CUSTOM_ID_NOT_DEFINED 9001

/* mat-object errors */
#define PLERR_MAT_NO_MATPIC 9200

/* errors for obj_create_tools */
#define PLERR_OBJ_CREATE_TOOL_OBJ_ID_NOT_SUPPORTED    9300
#define PLERR_OBJ_CREATE_TOOL_ID_STRING_ALREADY_USED  9301

/* errors for tools and tool-groups */
#define PLERR_CANT_CREATE_TOOL_GROUP 9400
#define PLERR_UNKNOWN_TOOL_GROUP 9401
#define PLERR_CANT_CREATE_TOOL 9402

/*****************************************************************************/
/*                       command codes fr RPI_do                            */
/*****************************************************************************/

/* user-interface functions **************************************************/
#define RPI_FREE_MYSELF FPLUG_USER_MESSAGE+1
#define RPI_GET_REF_INFO FPLUG_USER_MESSAGE+2
#define RPI_GET_REF_CHAR_INFO FPLUG_USER_MESSAGE+3
#define RPI_GET_LAST_ERR FPLUG_USER_MESSAGE+4
#define RPI_DO_SKRIPT_COMMAND FPLUG_USER_MESSAGE+100
#define RPI_SET_TIMER FPLUG_USER_MESSAGE+101
#define RPI_KILL_TIMER FPLUG_USER_MESSAGE+102
#define RPI_MAKE_BUTTON_WIN FPLUG_USER_MESSAGE+103
#define RPI_CLOSE_BUTTON_WIN FPLUG_USER_MESSAGE+104
#define RPI_RELEASE_BUTTON FPLUG_USER_MESSAGE+105
#define RPI_PRESS_BUTTON FPLUG_USER_MESSAGE+106
#define RPI_GET_BUTTON_WIN_SIZE FPLUG_USER_MESSAGE+107
#define RPI_MESSAGE_WIN FPLUG_USER_MESSAGE+108
#define RPI_ASK_WIN FPLUG_USER_MESSAGE+109
#define RPI_GET_SELECTION FPLUG_USER_MESSAGE+110
#define RPI_GET_MULTI_SELECTION FPLUG_USER_MESSAGE+111
#define RPI_GET_STRING FPLUG_USER_MESSAGE+112
#define RPI_GET_INT FPLUG_USER_MESSAGE+113
#define RPI_GET_REAL FPLUG_USER_MESSAGE+114
#define RPI_GET_INFO FPLUG_USER_MESSAGE+115
#define RPI_PRINT FPLUG_USER_MESSAGE+116
#define RPI_GET_N_REALS FPLUG_USER_MESSAGE+117
#define RPI_GET_N_INTS FPLUG_USER_MESSAGE+118
#define RPI_GET_REQUESTER FPLUG_USER_MESSAGE+119
#define RPI_DISPOSE_REQUESTER FPLUG_USER_MESSAGE+120
#define RPI_CLOSE_REQUESTER FPLUG_USER_MESSAGE+121
#define RPI_START_PROZENT FPLUG_USER_MESSAGE+122
#define RPI_SET_PROZENT FPLUG_USER_MESSAGE+123
#define RPI_STOP_PROZENT FPLUG_USER_MESSAGE+124
#define RPI_SHOW_HELP FPLUG_USER_MESSAGE+125
#define RPI_REQUESTER_VALUES_CHANGED FPLUG_USER_MESSAGE+126
#define RPI_SET_SELECTION_SORT_FLAG FPLUG_USER_MESSAGE+127
#define RPI_CLOSE_HELP FPLUG_USER_MESSAGE+128
#define RPI_GET_REQUESTER_POS FPLUG_USER_MESSAGE+129

/* system functions **********************************************************/
#define RPI_ALLOC_MEM FPLUG_USER_MESSAGE+200
#define RPI_FREE_MEM FPLUG_USER_MESSAGE+201
#define RPI_NEW_HEAP FPLUG_USER_MESSAGE+202
#define RPI_HEAP_ALLOC_MEM FPLUG_USER_MESSAGE+203
#define RPI_HEAP_REALLOC_MEM FPLUG_USER_MESSAGE+204
#define RPI_HEAP_FREE_MEM FPLUG_USER_MESSAGE+205
#define RPI_CLOSE_HEAP FPLUG_USER_MESSAGE+206

/* object functions **********************************************************/
#define RPI_OBJ_NEW FPLUG_USER_MESSAGE+1000
#define RPI_OBJ_GET_ID FPLUG_USER_MESSAGE+1001
#define RPI_FIND_OBJ FPLUG_USER_MESSAGE+1003
#define RPI_OBJ_FREE FPLUG_USER_MESSAGE+1004
#define RPI_OBJ_COPY FPLUG_USER_MESSAGE+1005
#define RPI_OBJ_SET_NAME FPLUG_USER_MESSAGE+1006
#define RPI_OBJ_GET_NAME FPLUG_USER_MESSAGE+1007
#define RPI_OBJ_INFORM FPLUG_USER_MESSAGE+1008
#define RPI_OBJ_GET_CLASS_NAME FPLUG_USER_MESSAGE+1009
#define RPI_OBJ_IS_SUB_CLASS_OF FPLUG_USER_MESSAGE+1010
#define RPI_OBJ_LOCK FPLUG_USER_MESSAGE+1011
#define RPI_OBJ_UNLOCK FPLUG_USER_MESSAGE+1012
#define RPI_OBJ_ALLOWED FPLUG_USER_MESSAGE+1013
#define RPI_N_OBJS FPLUG_USER_MESSAGE+1014
#define RPI_GET_OBJS FPLUG_USER_MESSAGE+1015
#define RPI_OBJ_SET_VAR FPLUG_USER_MESSAGE+1016
#define RPI_OBJ_GET_VAR FPLUG_USER_MESSAGE+1017
#define RPI_OBJ_GET_NVARS FPLUG_USER_MESSAGE+1018
#define RPI_OBJ_IS_SUB_CLASS_OF1 FPLUG_USER_MESSAGE+1019

/* custom-data functions *****************************************************/
#define RPI_OBJ_CONNECT_CUSTOM_DATA FPLUG_USER_MESSAGE+1020
#define RPI_OBJ_DISCONNECT_CUSTOM_DATA FPLUG_USER_MESSAGE+1021
#define RPI_OBJ_GET_CUSTOM_DATA FPLUG_USER_MESSAGE+1022
#define RPI_ADD_CUSTOM_DATA_LOAD_SAVE FPLUG_USER_MESSAGE+1023
#define RPI_SUB_CUSTOM_DATA_LOAD_SAVE FPLUG_USER_MESSAGE+1024

/* geo-object functions ******************************************************/
#define RPI_GEO_SET_PT FPLUG_USER_MESSAGE+2000
#define RPI_GEO_GET_PT FPLUG_USER_MESSAGE+2001
#define RPI_GEO_NEW_PT FPLUG_USER_MESSAGE+2002
#define RPI_GEO_DELETE_PT FPLUG_USER_MESSAGE+2003
#define RPI_GEO_DELETE_SELECTED_PTS FPLUG_USER_MESSAGE+2004
#define RPI_GEO_GET_SELECTED_PTS FPLUG_USER_MESSAGE+2005
#define RPI_GEO_NPTS FPLUG_USER_MESSAGE+2006
#define RPI_GEO_NLINES FPLUG_USER_MESSAGE+2007
#define RPI_GEO_SET_MATERIAL FPLUG_USER_MESSAGE+2008
#define RPI_GEO_CLEAR_MATERIAL FPLUG_USER_MESSAGE+2009
#define RPI_GEO_GET_BBOX FPLUG_USER_MESSAGE+2010
#define RPI_GEO_GET_2D_BBOX FPLUG_USER_MESSAGE+2011
#define RPI_GEO_SELECT_PT FPLUG_USER_MESSAGE+2012
#define RPI_GEO_UNSELECT_PT FPLUG_USER_MESSAGE+2013
#define RPI_GEO_SELECT_ALL_PTS FPLUG_USER_MESSAGE+2014
#define RPI_GEO_UNSELECT_ALL_PTS FPLUG_USER_MESSAGE+2015
#define RPI_GEO_INSERT_SON FPLUG_USER_MESSAGE+2016
#define RPI_GEO_DELETE_FROM_HIRARCHIE FPLUG_USER_MESSAGE+2017
#define RPI_GEO_GET_FATHER FPLUG_USER_MESSAGE+2018
#define RPI_GEO_N_SONS FPLUG_USER_MESSAGE+2019
#define RPI_GEO_GET_SON FPLUG_USER_MESSAGE+2020
#define RPI_GEO_MOVE FPLUG_USER_MESSAGE+2021
#define RPI_GEO_SET FPLUG_USER_MESSAGE+2023
#define RPI_GEO_SIZE FPLUG_USER_MESSAGE+2024
#define RPI_GEO_AIM_TO FPLUG_USER_MESSAGE+2025
#define RPI_GEO_ROT FPLUG_USER_MESSAGE+2026
#define RPI_GEO_ROT_GLOBAL FPLUG_USER_MESSAGE+2027
#define RPI_GEO_SET_ORIENTATION FPLUG_USER_MESSAGE+2028
#define RPI_GEO_GET_ORIENTATION FPLUG_USER_MESSAGE+2029
#define RPI_GEO_MOVE_SELECTED_PTS FPLUG_USER_MESSAGE+2030
#define RPI_GEO_SIZE_SELECTED_PTS FPLUG_USER_MESSAGE+2031
#define RPI_GEO_ROT_SELECTED_PTS FPLUG_USER_MESSAGE+2032
#define RPI_GEO_NEXT_PT_2D FPLUG_USER_MESSAGE+2033
#define RPI_GEO_PTS_IN_RECT_2D FPLUG_USER_MESSAGE+2034
#define RPI_GEO_PT_2D_KOORD FPLUG_USER_MESSAGE+2035
#define RPI_GEO_INSERT_PT1 FPLUG_USER_MESSAGE+20036
#define RPI_GEO_INSERT_PT FPLUG_USER_MESSAGE+2036
#define RPI_GEO_N_SELECTED_PTS FPLUG_USER_MESSAGE+2037
#define RPI_GEO_PT_IS_SELECTED FPLUG_USER_MESSAGE+2038
#define RPI_GEO_PT_TO_WORLD FPLUG_USER_MESSAGE+2039
#define RPI_GEO_PT_FROM_WORLD FPLUG_USER_MESSAGE+2040
#define RPI_GEO_PT_TO_OTHER_GEO FPLUG_USER_MESSAGE+2041
#define RPI_GEO_GET_POS FPLUG_USER_MESSAGE+2042
#define RPI_GEO_PLOT_PT FPLUG_USER_MESSAGE+2043
#define RPI_GEO_REALLOC_PTS FPLUG_USER_MESSAGE+2044
#define RPI_GEO_GET_WK_POS FPLUG_USER_MESSAGE+2045
#define RPI_GEO_SET_WK_POS FPLUG_USER_MESSAGE+2046
#define RPI_GEO_SET_PTS FPLUG_USER_MESSAGE+2047
#define RPI_GEO_GET_PTS FPLUG_USER_MESSAGE+2048
#define RPI_GEO_GET_WK_BBOX FPLUG_USER_MESSAGE+2049
#define RPI_GEO_PROJEKT_PT FPLUG_USER_MESSAGE+2050

/* PKL functions *************************************************************/
#define RPI_PLOT_PKL FPLUG_USER_MESSAGE+3000
#define RPI_PKL_ADD FPLUG_USER_MESSAGE+3001
#define RPI_PKL_SUB FPLUG_USER_MESSAGE+3002
#define RPI_PKL_CENTER_OBJ FPLUG_USER_MESSAGE+3003
#define RPI_OBJ_IN_PKL FPLUG_USER_MESSAGE+3004
#define RPI_N_PKL_OBJS FPLUG_USER_MESSAGE+3005
#define RPI_GET_PKL_OBJS FPLUG_USER_MESSAGE+3006
#define RPI_SET_ANSICHT FPLUG_USER_MESSAGE+3007
#define RPI_GET_ANSICHT FPLUG_USER_MESSAGE+3008
#define RPI_GET_SKALA FPLUG_USER_MESSAGE+3009
#define RPI_SET_SKALA FPLUG_USER_MESSAGE+3010

/* geo-edit functions ********************************************************/
#define RPI_GEO_EDIT_INFORM FPLUG_USER_MESSAGE+4000
#define RPI_GEO_EDIT_GET_SELECTED_OBJ FPLUG_USER_MESSAGE+4001
#define RPI_GEO_EDIT_ADD_TOOL FPLUG_USER_MESSAGE+4002
#define RPI_GEO_EDIT_SUB_TOOL FPLUG_USER_MESSAGE+4003
#define RPI_GEO_EDIT_ADD_INTERACTIVE_TOOL FPLUG_USER_MESSAGE+4004
#define RPI_GEO_EDIT_SUB_INTERACTIVE_TOOL FPLUG_USER_MESSAGE+4005
#define RPI_GEO_EDIT_PKT_EDITOR FPLUG_USER_MESSAGE+4006
#define RPI_GEO_EDIT_PRESS_XTRA_BUTTON FPLUG_USER_MESSAGE+4007
#define RPI_GEO_EDIT_RELEASE_XTRA_BUTTON FPLUG_USER_MESSAGE+4008

/* dreiecks-object functions *************************************************/
#define RPI_DREI_NEW_DREI FPLUG_USER_MESSAGE+5000
#define RPI_DREI_SET_DREI FPLUG_USER_MESSAGE+5001
#define RPI_DREI_GET_DREI FPLUG_USER_MESSAGE+5002
#define RPI_DREI_SET_DREI_ART FPLUG_USER_MESSAGE+5003
#define RPI_DREI_GET_DREI_ART FPLUG_USER_MESSAGE+5004
#define RPI_DREI_SET_DREI_MATNR FPLUG_USER_MESSAGE+5005
#define RPI_DREI_GET_DREI_MATNR FPLUG_USER_MESSAGE+5006
#define RPI_DREI_DELETE_DREI FPLUG_USER_MESSAGE+5007
#define RPI_DREI_DELETE_DREIECKE FPLUG_USER_MESSAGE+5008
#define RPI_DREI_NDREI FPLUG_USER_MESSAGE+5009
#define RPI_DREI_SET_PLOTMODE FPLUG_USER_MESSAGE+5010
#define RPI_DREI_GET_PLOTMODE FPLUG_USER_MESSAGE+5011
#define RPI_DREI_MERGE FPLUG_USER_MESSAGE+5012
#define RPI_DREI_CLEAR FPLUG_USER_MESSAGE+5013
#define RPI_DREI_MELT_PTS FPLUG_USER_MESSAGE+5014
#define RPI_DREI_SET_DREI_MATOBJ FPLUG_USER_MESSAGE+5015
#define RPI_DREI_RECOMPUTE_MATS FPLUG_USER_MESSAGE+5016
#define RPI_DREI_GET_DREI_MATOBJ FPLUG_USER_MESSAGE+5017
#define RPI_DREI_REALLOC_DREI FPLUG_USER_MESSAGE+5018
#define RPI_DREI_GET_N_KOERPER FPLUG_USER_MESSAGE+5019
#define RPI_DREI_GET_KOERPER_N_DREIECKE FPLUG_USER_MESSAGE+5020       
#define RPI_DREI_GET_KOERPER_DREIECKE FPLUG_USER_MESSAGE+5021
#define RPI_DREI_GET_KOERPER_NAME FPLUG_USER_MESSAGE+5022
#define RPI_DREI_NEU_KOERPER FPLUG_USER_MESSAGE+5023
#define RPI_DREI_SET_KOERPER_MATERIAL FPLUG_USER_MESSAGE+5024
#define RPI_DREI_SET_KOERPER_TEXTUR_MATERIAL FPLUG_USER_MESSAGE+5025
#define RPI_DREI_CLONE_DREIOBJ FPLUG_USER_MESSAGE+5026

/* texture-uv-functions********************************************************/
#define RPI_DREI_GET_TEX_UV_MODE FPLUG_USER_MESSAGE+5050
#define RPI_DREI_SET_TEX_UV_MODE FPLUG_USER_MESSAGE+5051
#define RPI_DREI_GET_TEX_UV_COORD FPLUG_USER_MESSAGE+5052
#define RPI_DREI_SET_TEX_UV_COORD FPLUG_USER_MESSAGE+5053

/* krper-tool functions  ****************************************************/
#define RPI_DREI_KOERPER_RUND FPLUG_USER_MESSAGE+5100
#define RPI_DREI_KOERPER_ECKIG FPLUG_USER_MESSAGE+5101
#define RPI_DREI_KOERPER_UMDREHEN FPLUG_USER_MESSAGE+5102
#define RPI_DREI_KOERPER_LOESCHEN FPLUG_USER_MESSAGE+5103
#define RPI_DREI_KOERPER_OBJEKTE_LOESCHEN FPLUG_USER_MESSAGE+5104
#define RPI_DREI_KOERPER_GLEICHRICHTEN FPLUG_USER_MESSAGE+5105
#define RPI_DREI_KOERPER_DOPPELN FPLUG_USER_MESSAGE+5106
#define RPI_DREI_KOERPER_DREIOBJ FPLUG_USER_MESSAGE+5107

/* POL-object functions ******************************************************/
#define RPI_POL_IS_OPEN FPLUG_USER_MESSAGE+5300
#define RPI_POL_OPEN_CLOSE FPLUG_USER_MESSAGE+5301

/* POL2D-object functions ****************************************************/
#define RPI_POL2D_TRIANG FPLUG_USER_MESSAGE+5500

/* material-object functions *************************************************/
#define RPI_MAT_SET_COL FPLUG_USER_MESSAGE+6000
#define RPI_MAT_GET_COL FPLUG_USER_MESSAGE+6001

/* surface-object functions **************************************************/
#define RPI_SURF_SET_PARAMS FPLUG_USER_MESSAGE+6100
#define RPI_SURF_GET_PARAMS FPLUG_USER_MESSAGE+6101
#define RPI_SURF_SET_GLANZ FPLUG_USER_MESSAGE+6102
#define RPI_SURF_GET_GLANZ FPLUG_USER_MESSAGE+6103

/* partikel-object functions *************************************************/
#define RPI_PRT_SET_COL FPLUG_USER_MESSAGE+6500
#define RPI_PRT_GET_COL FPLUG_USER_MESSAGE+6501
#define RPI_PRT_SET_SIZE FPLUG_USER_MESSAGE+6502
#define RPI_PRT_GET_SIZE FPLUG_USER_MESSAGE+6503
#define RPI_PRT_SET_NPARAM FPLUG_USER_MESSAGE+6504
#define RPI_PRT_GET_NPARAM FPLUG_USER_MESSAGE+6505
#define RPI_PRT_SET_DATA FPLUG_USER_MESSAGE+6506
#define RPI_PRT_GET_DATA FPLUG_USER_MESSAGE+6507
#define RPI_PRT_NEW_PTS FPLUG_USER_MESSAGE+6508
#define RPI_PRT_SET_RANGE FPLUG_USER_MESSAGE+6509
#define RPI_PRT_SET_POS FPLUG_USER_MESSAGE+6510

/* kugel-object functions ****************************************************/
#define RPI_KUG_NEW_KUG FPLUG_USER_MESSAGE+6600
#define RPI_KUG_DEL_KUG FPLUG_USER_MESSAGE+6601
#define RPI_KUG_NKUG FPLUG_USER_MESSAGE+6602
#define RPI_KUG_SET_RAD FPLUG_USER_MESSAGE+6603
#define RPI_KUG_GET_RAD FPLUG_USER_MESSAGE+6604
#define RPI_KUG_GET_KUG_PKTNR FPLUG_USER_MESSAGE+6605
#define RPI_KUG_SET_KUGELN_MAT FPLUG_USER_MESSAGE+6606
#define RPI_KUG_SET_KUG_MAT FPLUG_USER_MESSAGE+6607
#define RPI_KUG_GET_KUG_MAT FPLUG_USER_MESSAGE+6608

/* directory functions *******************************************************/
#define RPI_REQUEST_FILE FPLUG_USER_MESSAGE+11000

/* file-operation functions **************************************************/
#define RPI_FILE_OPEN_READ_BINARY FPLUG_USER_MESSAGE+13000
#define RPI_FILE_OPEN_WRITE_BINARY FPLUG_USER_MESSAGE+13001
#define RPI_FILE_WRITE_BINARY FPLUG_USER_MESSAGE+13002
#define RPI_FILE_READ_BINARY FPLUG_USER_MESSAGE+13003
#define RPI_FILE_WRITE_SHORT FPLUG_USER_MESSAGE+13004
#define RPI_FILE_WRITE_LONG FPLUG_USER_MESSAGE+13005
#define RPI_FILE_WRITE_FLOAT FPLUG_USER_MESSAGE+13006
#define RPI_FILE_READ_SHORT FPLUG_USER_MESSAGE+13007
#define RPI_FILE_READ_LONG FPLUG_USER_MESSAGE+13008
#define RPI_FILE_READ_FLOAT FPLUG_USER_MESSAGE+13009
#define RPI_FILE_SET_POS FPLUG_USER_MESSAGE+13010
#define RPI_FILE_GET_POS FPLUG_USER_MESSAGE+13011
#define RPI_FILE_CLOSE FPLUG_USER_MESSAGE+13012
#define RPI_FILE_EXIST FPLUG_USER_MESSAGE+13013
#define RPI_FILE_LENGTH FPLUG_USER_MESSAGE+13014
#define RPI_FILE_READ_STRING FPLUG_USER_MESSAGE+13015
#define RPI_FILE_WRITE_STRING FPLUG_USER_MESSAGE+13016
#define RPI_FILE_OPEN_READ_TEXT FPLUG_USER_MESSAGE+13017
#define RPI_FILE_OPEN_WRITE_TEXT FPLUG_USER_MESSAGE+13018
#define RPI_FILE_READ_DOUBLE FPLUG_USER_MESSAGE+13019
#define RPI_FILE_WRITE_DOUBLE FPLUG_USER_MESSAGE+13020

/* scene functions ***********************************************************/
#define RPI_WRITE_OBJECTS FPLUG_USER_MESSAGE+13500
#define RPI_WRITE_SZENE FPLUG_USER_MESSAGE+13501
#define RPI_READ_SZENE FPLUG_USER_MESSAGE+13502

/* operations functions ******************************************************/
#define RPI_ADD_SINGLE_TOOL FPLUG_USER_MESSAGE+14000
#define RPI_SUB_SINGLE_TOOL FPLUG_USER_MESSAGE+14001

/* scene-loader/saver functions **********************************************/
#define RPI_ADD_SCENE_LOADER FPLUG_USER_MESSAGE+15000
#define RPI_ADD_SCENE_LOADER_EXT FPLUG_USER_MESSAGE+15001
#define RPI_ADD_SCENE_SAVER FPLUG_USER_MESSAGE+15002

/* pic-loader functions ******************************************************/
#define RPI_ADD_PIC_LOADER_SAVER FPLUG_USER_MESSAGE+15020

/* create functions **********************************************************/
#define RPI_ADD_CREATE_TOOL FPLUG_USER_MESSAGE+15500
#define RPI_SUB_CREATE_TOOL FPLUG_USER_MESSAGE+15501
#define RPI_ADD_CREATE1_TOOL FPLUG_USER_MESSAGE+15502
#define RPI_SUB_CREATE1_TOOL FPLUG_USER_MESSAGE+15503

/* object create functions ***************************************************/
#define RPI_ADD_OBJ_CREATE_TOOL FPLUG_USER_MESSAGE+15600
#define RPI_SUB_OBJ_CREATE_TOOL FPLUG_USER_MESSAGE+15601
// struct for variables/parameters for create-object-tools
typedef struct 
{
   long nvars;          // number of variables
   char **texte;        // array with nvars pointers to the variable names
   long *var_types;     // array with nvars type-informations for the variables
                        // folgende typen gibts:
                        // 1: string-variable
                        // 2: long variable
                        // 3: long-variable with slider
                        // 4: real variable
                        // 5: real-variable with slider
                        // 6: action-variable. this is a value that is simply incremented
   long *long_min_max;  // the min/max values for long-variables with sliders in
                        // the order of their definition
   float *real_min_max; // the min/max values for real-variables with sliders in
                        // the order of their definition
} plug_obj_create_param;

/* general tools *************************************************************/
#define RPI_ADD_TOOL_GROUP FPLUG_USER_MESSAGE+15700
#define RPI_SUB_TOOL_GROUP FPLUG_USER_MESSAGE+15701
#define RPI_ACTIVATE_TOOL_GROUP FPLUG_USER_MESSAGE+15702
#define RPI_DEACTIVATE_TOOL_GROUP FPLUG_USER_MESSAGE+15703

#define RPI_ADD_TOOL FPLUG_USER_MESSAGE+15704
#define RPI_SUB_TOOL FPLUG_USER_MESSAGE+15705
#define RPI_ACTIVATE_TOOL FPLUG_USER_MESSAGE+15706
#define RPI_DEACTIVATE_TOOL FPLUG_USER_MESSAGE+15707
#define RPI_SELECT_TOOL FPLUG_USER_MESSAGE+15708
#define RPI_DESELECT_TOOL FPLUG_USER_MESSAGE+15709

/* defines for tool-groups, flags */
/* tool-group is contained in menu */
#define GROUP_FLAG_MENU 1
/* tool-group should have its own icon-bar */
#define GROUP_FLAG_LEISTE 2

/* kant-geo-object-functions *************************************************/
#define RPI_KANT_GEO_ALLOC_KANTEN FPLUG_USER_MESSAGE+16000
#define RPI_KANT_GEO_SET_KANTE FPLUG_USER_MESSAGE+16001
#define RPI_KANT_GEO_SET_FLAGS FPLUG_USER_MESSAGE+16002
#define RPI_KANT_GEO_GET_FLAGS FPLUG_USER_MESSAGE+16003
#define RPI_KANT_GEO_SET_COLOR FPLUG_USER_MESSAGE+16004
#define RPI_KANT_GEO_GET_COLOR FPLUG_USER_MESSAGE+16005
/* kant-geo-flags */
#define KG_FLAG_PLOT_PTS 1
/* color index for set/get color */
#define KG_COL_PTS 0
#define KG_COL_LINES 1

/* plugin data-save/load functions *******************************************/
#define RPI_GET_OBJ_SAVE_HANDLES FPLUG_USER_MESSAGE+16100
#define RPI_GET_OBJ_LOAD_POINTERS FPLUG_USER_MESSAGE+16101

/* plot triangles functions **************************************************/
#define RPI_PLOT_TRIANGLES FPLUG_USER_MESSAGE+16500
/* defines for plot triangles */
#define PLOT_COLOR_BACKGROUND 0
#define PLOT_COLOR_NORMAL 1
#define PLOT_COLOR_OBJ_SELECTED 2
#define PLOT_COLOR_PTS_SELECTED 3
#define PLOT_COLOR_RED 4
#define PLOT_COLOR_GREEN 5
#define PLOT_COLOR_BLUE 6
#define PLOT_COLOR_WHITE 7
#define PLOT_COLOR_BLACK 8

/* anim-fx functions *********************************************************/
#define RPI_AFX_SET_N_OBJ_VARS         FPLUG_USER_MESSAGE+100000
#define RPI_AFX_DEFINE_OBJ_VAR         FPLUG_USER_MESSAGE+100001
#define RPI_AFX_DEFINE_OBJ_RGB_VAR     FPLUG_USER_MESSAGE+100002
#define RPI_AFX_ALLOK_INTERN_VARS      FPLUG_USER_MESSAGE+100003
#define RPI_AFX_SET_REAL               FPLUG_USER_MESSAGE+100004
#define RPI_AFX_GET_REAL               FPLUG_USER_MESSAGE+100005
#define RPI_AFX_SET_INT                FPLUG_USER_MESSAGE+100006
#define RPI_AFX_GET_INT                FPLUG_USER_MESSAGE+100007
#define RPI_AFX_SET_OBJ                FPLUG_USER_MESSAGE+100008
#define RPI_AFX_GET_OBJ                FPLUG_USER_MESSAGE+100009
#define RPI_AFX_SET_USER_DATA          FPLUG_USER_MESSAGE+100010
#define RPI_AFX_GET_USER_DATA          FPLUG_USER_MESSAGE+100011
#define RPI_AFX_USE_CUSTOM_EDITOR      FPLUG_USER_MESSAGE+100012

/* anim-fx return codes */
#define PLI_AFX_RET_ERR       0
#define PLI_AFX_RET_ABBRUCH   1
#define PLI_AFX_RET_OK        2

/* anim-fx info messages */
#define PLI_AFX_STORE_INFO    1

/* functions for displays ****************************************************/
#define RPI_OPEN_DISP MON5_MESSAGE+0
#define RPI_CLOSE_DISP MON5_MESSAGE+1
/* flags for open_disp */
#define DISP_WINDOW 1
#define DISP_RESIZE 2
/* RGB-modes */
#define RGB_MODE_RGB 1
#define RGB_MODE_DIB 2
/* enums for disp_set_font */
#define DISP_TEXT_SIZE_SYSTEM 0
#define DISP_TEXT_SIZE_SMALL  1
#define DISP_TEXT_SIZE_MEDIUM 2
#define DISP_TEXT_SIZE_LARGE  3
#define DISP_TEXT_SIZE_HUGE   4
/* flags for disp_text1 */
#define DISP_TEXT_ITALIC   1
#define DISP_TEXT_BOLD     2

#define RPI_DISP_SET_COL MON5_MESSAGE+2
#define RPI_DISP_GET_COL MON5_MESSAGE+3
#define RPI_DISP_SET_PIXEL MON5_MESSAGE+4
#define RPI_DISP_SET_MULTI_PIXEL MON5_MESSAGE+5
#define RPI_DISP_MOVETO MON5_MESSAGE+6
#define RPI_DISP_DRAWTO MON5_MESSAGE+7
#define RPI_DISP_POLYLINE MON5_MESSAGE+8
#define RPI_DISP_POLYSEGMENT MON5_MESSAGE+9
#define RPI_DISP_POLYTRIANGLES MON5_MESSAGE+10
#define RPI_DISP_FILLRECT MON5_MESSAGE+11
#define RPI_DISP_SETRECT MON5_MESSAGE+12
#define RPI_DISP_GETRECT MON5_MESSAGE+13
#define RPI_DISP_SET_CLIP MON5_MESSAGE+14
#define RPI_DISP_GET_CLIP MON5_MESSAGE+15
#define RPI_DISP_FULL_CLIP MON5_MESSAGE+16
#define RPI_DISP_GET_RGB_MODE MON5_MESSAGE+17
#define RPI_DISP_GET_RGB_BUFFER MON5_MESSAGE+18
#define RPI_DISP_BUFFER_FLUSH MON5_MESSAGE+19
#define RPI_DISP_REFRESH_WINDOW MON5_MESSAGE+20
#define RPI_DISP_REFRESH_WINDOW_CLIP MON5_MESSAGE+21
#define RPI_DISP_GET_SIZE MON5_MESSAGE+22
#define RPI_DISP_TEXT MON5_MESSAGE+23
#define RPI_DISP_GET_TEXT_SIZE MON5_MESSAGE+24
#define RPI_DISP_SET_MULTI_COLOR_PIXEL MON5_MESSAGE+25
#define RPI_DISP_GET_PIXEL MON5_MESSAGE+26
#define RPI_DISP_GET_MULTI_PIXEL MON5_MESSAGE+27
#define RPI_RESIZE_DISP MON5_MESSAGE+28
#define RPI_DISP_SETRECT_ALPHA MON5_MESSAGE+29
#define RPI_DISP_COPY_RECT_ALPHA MON5_MESSAGE+30
#define RPI_DISP_SET_FONT MON5_MESSAGE+31
#define RPI_DISP_TEXT1 MON5_MESSAGE+32
#define RPI_LOAD_PIC_GET_DISP MON5_MESSAGE+33
#define RPI_DISP_PROJECT_PT MON5_MESSAGE+34
#define RPI_DISP_GET_CAMERA MON5_MESSAGE+35
#define RPI_DISP_IS_KEY_USED MON5_MESSAGE+36
#define RPI_DISP_GET_POS MON5_MESSAGE+37

/* new-material-functions ****************************************************/
#define RPI_MAT_GET_PIC_SIZE MON5_MESSAGE+1000
#define RPI_MAT_GET_PIC_DATA MON5_MESSAGE+1001
#define RPI_MAT_GET_PIC_DATA_DIB MON5_MESSAGE+1002

/* afterburner functions *****************************************************/
#define RPI_NEW_AFTER_BURNER MON5_MESSAGE+1500
#define RPI_DEL_AFTER_BURNER MON5_MESSAGE+1501

#define RPI_AFTER_BURNER_GET_OBJ_KANAL MON5_MESSAGE+1502
#define RPI_AFTER_BURNER_RELEASE_OBJ_KANAL MON5_MESSAGE+1503
#define RPI_AFTER_BURNER_GET_KANAL_MAP MON5_MESSAGE+1504
#define RPI_AFTER_BURNER_ALLOC_DEPTHBUFF MON5_MESSAGE+1506
#define RPI_AFTER_BURNER_FREE_DEPTHBUFF MON5_MESSAGE+1507
#define RPI_AFTER_BURNER_GET_PIXEL_DEPTH MON5_MESSAGE+1508
#define RPI_AFTER_BURNER_GET_MULTI_PIXEL_DEPTH MON5_MESSAGE+1509
#define RPI_AFTER_BURNER_GET_DEPTHBUFF_BACKGROUND_VALUE MON5_MESSAGE+1510
#define RPI_AFTER_BURNER_GET_PIXEL_RECT_DEPTH MON5_MESSAGE+1511

#define RPI_GET_AKT_KAM MON5_MESSAGE+1600
#define RPI_SET_AKT_KAM MON5_MESSAGE+1601

/*****************************************************************************/
/* bitmasks for object edit locking (disable/enable) */

#define RIGHT_NO_RENDER      0x00400000
#define RIGHT_OBJ_DELETE     0x00000001 
#define RIGHT_GEO_CHANGE     0x00000100
#define RIGHT_GEO_HIRA_TO    0x00000200
#define RIGHT_GEO_TO_HIRA    0x00002000
#define RIGHT_GEO_HIRARCHIE  (RIGHT_GEO_HIRA_TO|RIGHT_GEO_TO_HIRA)
#define RIGHT_GEO_PTS_CHANGE 0x00000400
#define RIGHT_GEO_TOPOL      0x00000800
#define RIGHT_ALL_RIGHTS\
        (RIGHT_OBJ_DELETE|RIGHT_GEO_CHANGE|RIGHT_GEO_HIRARCHIE\
        |RIGHT_GEO_PTS_CHANGE|RIGHT_GEO_TOPOL)

/*****************************************************************************/
/* defines for non-modal requester */

#define CODE_STRING             0
#define CODE_INT                1
#define CODE_REAL               2
#define CODE_CYCLE              3
#define CODE_INT_EXTENDED       4
#define CODE_REAL_EXTENDED      5
#define CODE_LINE               7
#define CODE_TEXT               8

/*****************************************************************************/

#endif

/*****************************************************************************/
