/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/

/* title:    triangle object functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  23.3.98 by RG */
/* version:  1.1 25.8.99 monzoom5-functions */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */

/*****************************************************************************/
/* create a new triangle */

   RPIStub long
RPI_drei_new_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long p,long q,long r,long *dreinr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      p,q,r:       index numbers of the triangle vertices
      dreinr:      destination for the index number of the new triangle
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_NEW_DREI;
   in.v_param[1]=obj;
   in.l_param[0]=p;
   in.l_param[1]=q;
   in.l_param[2]=r;
   if (0!=(ret=RPI_do(&in,&out)))
      *dreinr=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* set the vertices of an existing triangle */

   RPIStub long
RPI_drei_set_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long p,long q,long r)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of the triangle
      p,q,r:       new index numbers of the triangle vertices
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_DREI;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   in.l_param[1]=p;
   in.l_param[2]=q;
   in.l_param[3]=r;   
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the index numbers of an existing triangle */

   RPIStub long
RPI_drei_get_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long *p,long *q,long *r)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      p,q,r:       destination for index numbers of the triangle vertices
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_DREI;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   if (0!=(ret=RPI_do(&in,&out))) {
     *p=out.l_param[0];
     *q=out.l_param[1];
     *r=out.l_param[2];
   }
   return(ret);
}
/*****************************************************************************/
/* get the number of triangles of an object */

   RPIStub long 
RPI_drei_ndrei
   (RPI_HANDLE handle,RPI_OBJECT obj,long *ndrei)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      ndrei:       destination for the number of triangles
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_NDREI;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
     *ndrei=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* set the smooth flag of a triangle */

   RPIStub long
RPI_drei_set_drei_art
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long rund_art)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      rund_art:    smoothing type for triangle, 0=flat, !=0=rounded
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_DREI_ART;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   in.l_param[1]=rund_art;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the smooth flag of a triangle */

   RPIStub long
RPI_drei_get_drei_art
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long *rund_art)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      rund_art:    destination for smoothing type of triangle
                   0=flat, !=0=rounded
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_DREI_ART;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   if (0!=(ret=RPI_do(&in,&out)))
     *rund_art=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* set the material of a triangle */

   RPIStub long
RPI_drei_set_drei_matnr
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long matnr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matnr:       the internal number of the material, 0=no material
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_DREI_MATNR;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   in.l_param[1]=matnr;
   
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* set the material of a triangle not by the internal nr (which may not exist)
   but by the object-handle of a material-object
*/
   RPIStub long
RPI_drei_set_drei_matobj
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,RPI_OBJECT matobj)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matobj:      object-handle of the triangle material
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_DREI_MATOBJ;
   in.v_param[1]=obj;
   in.v_param[2]=matobj;
   in.l_param[0]=dreinr;
   
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the internal nr of a material of a triangle */

   RPIStub long
RPI_drei_get_drei_matnr
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long *matnr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matnr:       destination for the internal number of the material
                   0=no material
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_DREI_MATNR;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   if (0!=(ret=RPI_do(&in,&out)))
     *matnr=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* get the material object of a triangle */

   RPIStub long
RPI_drei_get_drei_matobj
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,RPI_OBJECT *matobj)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matobj:      object-handle of the triangle material
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_DREI_MATOBJ;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   if (0!=(ret=RPI_do(&in,&out)))
     *matobj=out.v_param[0];
   return(ret);   
}
/*****************************************************************************/
/* recomputes the internal material-information of an triangle-object. must be
   called after a series of RPI_drei_set_matnr/RPI_drei_set_matobj calls! 
*/
   RPIStub long
RPI_drei_recompute_mats
   (RPI_HANDLE handle,RPI_OBJECT obj)
{   
   /* handle:      refgateway-handle
      obj:         object-handle
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_RECOMPUTE_MATS;
   in.v_param[1]=obj;
   
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* delete a single triangle */

   RPIStub long
RPI_drei_delete_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle to delete
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_DELETE_DREI;
   in.v_param[1]=obj;
   in.l_param[0]=dreinr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* delete triangles specified in array with index numbers */

   RPIStub long
RPI_drei_delete_dreiecke
   (RPI_HANDLE handle,RPI_OBJECT obj,long n_loesch,long *loesch_nrn)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      n_loesch:    nr of triangles to delete
      loesch_nrn:  array[n_loesch] with index numbers of triangles
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_DELETE_DREIECKE;
   in.v_param[1]=obj;
   in.l_param[0]=n_loesch;
   in.v_param[2]=(void *)loesch_nrn;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* set the plotmode for an object */

   RPIStub long
RPI_drei_set_plotmode
   (RPI_HANDLE handle,RPI_OBJECT obj,long hidd)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      hidd:        plotmode: 0=hidd0, 1=hidd1, 2=hidd2
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_PLOTMODE;
   in.v_param[1]=obj;
   in.l_param[0]=hidd;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the plotmode of an object */

   RPIStub long
RPI_drei_get_plotmode
   (RPI_HANDLE handle,RPI_OBJECT obj,long *hidd)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      hidd:        destination for plotmode: 0=hidd0, 1=hidd1, 2=hidd2
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_PLOTMODE;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
      *hidd=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* merge two triangle objects */

   RPIStub long
RPI_drei_merge
   (RPI_HANDLE handle,RPI_OBJECT obj,RPI_OBJECT obj1,long with_kp)
{
   /* handle:      refgateway-handle
      obj:         object-handle 
      obj1:        object-handle of object to be merged with obj
      with_kp:     flag: 0=do not add "Krper" of obj1, !=0=add "Krper"
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_MERGE;
   in.v_param[1]=obj;
   in.v_param[2]=obj1;
   in.l_param[0]=with_kp;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* delete all triangles of an object */

   RPIStub long
RPI_drei_clear_drei
   (RPI_HANDLE handle,RPI_OBJECT obj)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_CLEAR;
   in.v_param[1]=obj;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* melt points within a specified distance to a single point */
   
   RPIStub long
RPI_drei_melt_pts
   (RPI_HANDLE handle,RPI_OBJECT obj,float delta,long selected_flag,
    long von,long bis,long *n_melted)
{
   /* handle:        refgateway-handle
      obj:           object-handle
      delta:         maximum distance of points to be melted
      selected_flag: flag: 0=use range von to bis, !=0=process selected points
      von:           if selected_flag=0: first point to process      
      bis:           if selected_flag=0: last point to process
      n_melted:      destination for the number of melted points
      returns:       0 if failed
                     1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_MELT_PTS;
   in.v_param[1]=obj;
   in.f_param[0]=delta;
   in.l_param[0]=selected_flag;
   in.l_param[1]=von;
   in.l_param[2]=bis;
   if (0!=(ret=RPI_do(&in,&out)))
      *n_melted=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* set the triangle buffer of an object */

   RPIStub long
RPI_drei_realloc_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long ndrei)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      ndrei:       number of triangles in the internal buffer to allocate
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_REALLOC_DREI;
   in.v_param[1]=obj;
   in.l_param[0]=ndrei;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the number of krpers of a triangle-object */

   RPIStub long
RPI_drei_get_n_koerper
   (RPI_HANDLE handle,RPI_OBJECT obj,long *nkoerper)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      nkoerper:    destination for the number of krpers
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_N_KOERPER;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
    *nkoerper=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* get the name of a krper of a triangle-object */

   RPIStub long
RPI_drei_get_koerper_name
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,char *name)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      name:        destination for name of the krper
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_KOERPER_NAME;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   out.s_param[0]=name;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the number of triangles of a krper */

   RPIStub long
RPI_drei_get_koerper_n_dreiecke
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,long *ndrei)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      ndrei:       destination for the number of triangles
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_KOERPER_N_DREIECKE;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   if (0!=(ret=RPI_do(&in,&out)))
     *ndrei=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* get the triangle numbers of all triangles of a krper */

   RPIStub long
RPI_drei_get_koerper_dreiecke
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,long *dreiecke)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      dreiecke:    destination for the triangles
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_KOERPER_DREIECKE;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   in.v_param[2]=dreiecke;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* define a new krper for a triangle-object */

   RPIStub long
RPI_drei_neu_koerper
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name,long ndrei,long *dreiecke)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      ndrei:       number of triangles for the new koerper
      dreiecke:    triangle-numbers for the new koerper
      name:        name for the koerper (check after return! may be changed
                   because an object with this name already exists)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_NEU_KOERPER;
   in.v_param[1]=obj;
   in.l_param[0]=ndrei;
   in.v_param[2]=dreiecke;
   in.s_param[0]=name;
   out.s_param[0]=name;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* set the material of all triangles of a krper */

   RPIStub long
RPI_drei_set_koerper_material
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,RPI_OBJECT mat)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      mat:         object-handle for the material
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_KOERPER_MATERIAL;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   in.v_param[2]=mat;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* set the texture-material of all triangles of a krper */

   RPIStub long
RPI_drei_set_koerper_textur_material
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,
   RPI_OBJECT texmat,long abbildung,RPI_OBJECT *txo)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      abbildung:   projection type 0=flat,1=cylinder,2=sphere
                   (ignored if the material is a procedural texture)
      texmat:      object-handle for texture-material or mathe-textur-mat
      *txo         destination for created texture-object
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_KOERPER_TEXTUR_MATERIAL;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   in.l_param[1]=abbildung;
   in.v_param[2]=texmat;
   if (0!=(ret=RPI_do(&in,&out)))
     *txo=out.v_param[0];
   return(ret);
}
/*****************************************************************************/
/* set the smooth-flag of all triangles of a krper */

   RPIStub long
RPI_drei_koerper_rund
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_RUND;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* clear the smooth-flag of all triangles of a krper */

   RPIStub long
RPI_drei_koerper_eckig
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_ECKIG;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* changes the order of all vertices of all triangles of a krper */
   
   RPIStub long
RPI_drei_koerper_umdrehen
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_UMDREHEN;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* deletes a krper (only the krper, not its triangles!)*/

   RPIStub long
RPI_drei_koerper_loeschen
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_LOESCHEN;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* deletes a krper and its triangles 
   !! CAUTION !!
   this function may also delete other krpers of the triangle-object.
   after calling this function you have to update all your previously
   stored krper indices.
*/
   RPIStub long
RPI_drei_koerper_objekte_loeschen
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_OBJEKTE_LOESCHEN;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* equalizes the triangles of a krper (gives all triangles of a krper
   the same point-order if possible).
*/
   RPIStub long
RPI_drei_koerper_gleichrichten
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr)
{
   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_GLEICHRICHTEN;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* doubles a krper (doubles all pts and triangles and texture-objects ) */

   RPIStub long
RPI_drei_koerper_doppeln
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,char *desired_name)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      koerper_nr:   krper-number (0..#krper-1)
      desired_name: desired name for new krper
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_DOPPELN;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   in.s_param[0]=desired_name;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* make a new triangle object from a krper.
   alle points,triangles and textur-objects of the krper will be copied
   into a new triangle object. the krper will then be deleted.
   (this may delete other krpers, so if you further work with krper-nrs of
   that object you have to ask again for the number of krpers.
*/
   RPIStub long
RPI_drei_koerper_dreiobj
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,
   char *desired_name,RPI_OBJECT *new_dreiobj)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      koerper_nr:   krper-number (0..#krper-1)
      desired_name: desired name for new triangle object
      new_dreiobj:  destination for the new triangle objekt handle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_KOERPER_DREIOBJ;
   in.v_param[1]=obj;
   in.l_param[0]=koerper_nr;
   in.s_param[0]=desired_name;
   if (0!=(ret=RPI_do(&in,&out)))
      *new_dreiobj=out.v_param[0];
   return(ret);
}
/*****************************************************************************/

#if MONZOOM_VERSION >= 45

/*****************************************************************************/
/* clones a triangle object */

   RPIStub long
RPI_drei_clone_dreiobj
   (RPI_HANDLE handle,RPI_OBJECT obj,char *desired_name,RPI_OBJECT *new_dreiobj)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      koerper_nr:   krper-number (0..#krper-1)
      desired_name: desired name for new triangle object
      new_dreiobj:  destination for the new triangle objekt handle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_CLONE_DREIOBJ;
   in.v_param[1]=obj;
   in.s_param[0]=desired_name;
   if (0!=(ret=RPI_do(&in,&out)))
      *new_dreiobj=out.v_param[0];
   return(ret);
}
/*****************************************************************************/
/* texture-uv-functions */
/* asks for the texture-uv-mapping-mode of a triangle-object */

   RPIStub long
RPI_drei_get_tex_uv_mode
   (RPI_HANDLE handle,RPI_OBJECT obj,long *mode)
{
   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      mode:         destination for texture-uv-mode
                    (0= no uv-mapping, 1=uv-mapping)
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_TEX_UV_MODE;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
      *mode=out.l_param[0];
   return(ret);

}
/*****************************************************************************/
/* set the textur-uv-mapping-mode of a triangle-object */

   RPIStub long
RPI_drei_set_tex_uv_mode
   (RPI_HANDLE handle,RPI_OBJECT obj,long mode)
{
   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      mode:         texture-uv-mapping-mode
                    (0= no uv-mapping, 1=uv-mapping)
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_TEX_UV_MODE;
   in.v_param[1]=obj;
   in.l_param[0]=mode;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* asks for the texture-uv-mapping-coordinates of a single triangle of a triangle-object */

   RPIStub long
RPI_drei_get_tex_uv_coord
   (RPI_HANDLE handle,RPI_OBJECT obj,long drei_nr,float *uvw_param)
{
   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      drei_nr:      nr of triangle
      uvw_param:    destination for uvw-params of the vertices of the triangle (9 floats)
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long i,ret;

   in.v_param[0]=handle;
   in.id=RPI_DREI_GET_TEX_UV_COORD;
   in.v_param[1]=obj;
   in.l_param[0]=drei_nr;
   if (0!=(ret=RPI_do(&in,&out))) {
      for (i=0;i<9;i++) uvw_param[i]=out.f_param[i];
   }
   return(ret);

}
/*****************************************************************************/
/* sets the texture-uv-mapping-coordinates of a single triangle of a triangle-object */

   RPIStub long
RPI_drei_set_tex_uv_coord
   (RPI_HANDLE handle,RPI_OBJECT obj,long drei_nr,float *uvw_param)
{
   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      drei_nr:      nr of triangle
      uvw_param:    the uvw-params of the vertices of the triangle (9 floats)
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long i;

   in.v_param[0]=handle;
   in.id=RPI_DREI_SET_TEX_UV_COORD;
   in.v_param[1]=obj;
   in.l_param[0]=drei_nr;
   for (i=0;i<9;i++) in.f_param[i]=uvw_param[i];
   return(RPI_do(&in,&out));    
}
/*****************************************************************************/

#endif /* if MONZOOM_VERSION >= 45 */

/*****************************************************************************/
