/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    triangle object functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  23.3.98 by RG */
/* version:  1.1 25.8.99 monzoom5-functions */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
/* create a new triangle */

   RPIStub long
RPI_drei_new_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long p,long q,long r,long *dreinr);

   /* handle:      refgateway-handle
      obj:         object-handle
      p,q,r:       index numbers of the triangle vertices
      dreinr:      destination for the index number of the new triangle
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the vertices of an existing triangle */

   RPIStub long
RPI_drei_set_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long p,long q,long r);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of the triangle
      p,q,r:       new index numbers of the triangle vertices
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the index numbers of an existing triangle */

   RPIStub long
RPI_drei_get_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long *p,long *q,long *r);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      p,q,r:       destination for index numbers of the triangle vertices
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the number of triangles of an object */

   RPIStub long
RPI_drei_ndrei
   (RPI_HANDLE handle,RPI_OBJECT obj,long *ndrei);

   /* handle:      refgateway-handle
      obj:         object-handle
      ndrei:       destination for the number of triangles
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the smooth flag of a triangle */

   RPIStub long
RPI_drei_set_drei_art
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long rund_art);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      rund_art:    smoothing type for triangle, 0=flat, !=0=rounded
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the smooth flag of a triangle */

   RPIStub long
RPI_drei_get_drei_art
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long *rund_art);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      rund_art:    destination for smoothing type of triangle
                   0=flat, !=0=rounded
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the material of a triangle */

   RPIStub long
RPI_drei_set_drei_matnr
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long matnr);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matnr:       the internal number of the material, 0=no material
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the material of a triangle not by the internal nr (which may not exist)
   but by the object-handle of a material-object
*/

   RPIStub long
RPI_drei_set_drei_matobj
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,RPI_OBJECT matobj);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matobj:      object-handle of the triangle material
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the internal nr of a material of a triangle */

   RPIStub long
RPI_drei_get_drei_matnr
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,long *matnr);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matnr:       destination for the internal number of the material
                   0=no material
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the material object of a triangle */

   RPIStub long
RPI_drei_get_drei_matobj
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr,RPI_OBJECT *matobj);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle
      matobj:      object-handle of the triangle material
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* recomputes the internal material-information of an triangle-object. must be
   called after a series of RPI_drei_set_matnr/RPI_drei_set_matobj calls!
*/

   RPIStub long
RPI_drei_recompute_mats
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:      refgateway-handle
      obj:         object-handle
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* delete a single triangle */

   RPIStub long
RPI_drei_delete_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long dreinr);

   /* handle:      refgateway-handle
      obj:         object-handle
      dreinr:      index number of triangle to delete
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* delete triangles specified in array with index numbers */

   RPIStub long
RPI_drei_delete_dreiecke
   (RPI_HANDLE handle,RPI_OBJECT obj,long n_loesch,long *loesch_nrn);

   /* handle:      refgateway-handle
      obj:         object-handle
      n_loesch:    nr of triangles to delete
      loesch_nrn:  array[n_loesch] with index numbers of triangles
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the plotmode for an object */

   RPIStub long
RPI_drei_set_plotmode
   (RPI_HANDLE handle,RPI_OBJECT obj,long hidd);

   /* handle:      refgateway-handle
      obj:         object-handle
      hidd:        plotmode: 0=hidd0, 1=hidd1, 2=hidd2
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the plotmode of an object */

   RPIStub long
RPI_drei_get_plotmode
   (RPI_HANDLE handle,RPI_OBJECT obj,long *hidd);

   /* handle:      refgateway-handle
      obj:         object-handle
      hidd:        destination for plotmode: 0=hidd0, 1=hidd1, 2=hidd2
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* merge two triangle objects */

   RPIStub long
RPI_drei_merge
   (RPI_HANDLE handle,RPI_OBJECT obj,RPI_OBJECT obj1,long with_kp);

   /* handle:      refgateway-handle
      obj:         object-handle
      obj1:        object-handle of object to be merged with obj
      with_kp:     flag: 0=do not add "Krper" of obj1, !=0=add "Krper"
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* delete all triangles of an object */

   RPIStub long
RPI_drei_clear_drei
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:      refgateway-handle
      obj:         object-handle
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* melt points within a specified distance to a single point */

   RPIStub long
RPI_drei_melt_pts
   (RPI_HANDLE handle,RPI_OBJECT obj,float delta,long selected_flag,
    long von,long bis,long *n_melted);

   /* handle:        refgateway-handle
      obj:           object-handle
      delta:         maximum distance of points to be melted
      selected_flag: flag: 0=use range von to bis, !=0=process selected points
      von:           if selected_flag=0: first point to process
      bis:           if selected_flag=0: last point to process
      n_melted:      destination for the number of melted points
      returns:       0 if failed
                     1 if ok
   */
/*****************************************************************************/
/* set the triangle buffer of an object */

   RPIStub long
RPI_drei_realloc_drei
   (RPI_HANDLE handle,RPI_OBJECT obj,long ndrei);

   /* handle:      refgateway-handle
      obj:         object-handle
      ndrei:       number of triangles in the internal buffer to allocate
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the number of krpers of a triangle-object */

   RPIStub long
RPI_drei_get_n_koerper
   (RPI_HANDLE handle,RPI_OBJECT obj,long *nkoerper);

   /* handle:      refgateway-handle
      obj:         object-handle
      nkoerper:    destination for the number of krpers
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the name of a krper of a triangle-object */

   RPIStub long
RPI_drei_get_koerper_name
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,char *name);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      name:        destination for name of the krper
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the number of triangles of a krper */

   RPIStub long
RPI_drei_get_koerper_n_dreiecke
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,long *ndrei);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      ndrei:       destination for the number of triangles
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the triangle numbers of all triangles of a krper */

   RPIStub long
RPI_drei_get_koerper_dreiecke
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,long *dreiecke);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      dreiecke:    destination for the triangles
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* define a new krper for a triangle-object */

   RPIStub long
RPI_drei_neu_koerper
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name,long ndrei,long *dreiecke);

   /* handle:      refgateway-handle
      obj:         object-handle
      ndrei:       number of triangles for the new koerper
      dreiecke:    triangle-numbers for the new koerper
      name:        name for the koerper (check after return! may be changed
                   because an object with this name already exists)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the material of all triangles of a krper */

   RPIStub long
RPI_drei_set_koerper_material
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,RPI_OBJECT mat);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      mat:         object-handle for the material
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the texture-material of all triangles of a krper */

   RPIStub long
RPI_drei_set_koerper_textur_material
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,
   RPI_OBJECT texmat,long abbildung,RPI_OBJECT *txo);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      abbildung:   projection type 0=flat,1=cylinder,2=sphere
                   (ignored if the material is a procedural texture)
      texmat:      object-handle for texture-material or mathe-textur-mat
      *txo         destination for created texture-object
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the smooth-flag of all triangles of a krper */

   RPIStub long
RPI_drei_koerper_rund
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* clear the smooth-flag of all triangles of a krper */

   RPIStub long
RPI_drei_koerper_eckig
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* changes the order of all vertices of all triangles of a krper */

   RPIStub long
RPI_drei_koerper_umdrehen
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* deletes a krper (only the krper, not its triangles!)*/

   RPIStub long
RPI_drei_koerper_loeschen
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* deletes a krper and its triangles
   !! CAUTION !!
   this function may also delete other krpers of the triangle-object.
   after calling this function you have to update all your previously
   stored krper indices.
*/

   RPIStub long
RPI_drei_koerper_objekte_loeschen
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* equalizes the triangles of a krper (gives all triangles of a krper
   the same point-order if possible).
*/

   RPIStub long
RPI_drei_koerper_gleichrichten
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr);

   /* handle:      refgateway-handle
      obj:         object-handle
      koerper_nr:  krper-number (0..#krper-1)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* doubles a krper (doubles all pts and triangles and texture-objects ) */

   RPIStub long
RPI_drei_koerper_doppeln
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,char *desired_name);

   /* handle:       refgateway-handle
      obj:          object-handle
      koerper_nr:   krper-number (0..#krper-1)
      desired_name: desired name for new krper
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* make a new triangle object from a krper.
   alle points,triangles and textur-objects of the krper will be copied
   into a new triangle object. the krper will then be deleted.
   (this may delete other krpers, so if you further work with krper-nrs of
   that object you have to ask again for the number of krpers.
*/

   RPIStub long
RPI_drei_koerper_dreiobj
   (RPI_HANDLE handle,RPI_OBJECT obj,long koerper_nr,
   char *desired_name,RPI_OBJECT *new_dreiobj);

   /* handle:       refgateway-handle
      obj:          object-handle
      koerper_nr:   krper-number (0..#krper-1)
      desired_name: desired name for new triangle object
      new_dreiobj:  destination for the new triangle objekt handle
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#if MONZOOM_VERSION >= 45
/*****************************************************************************/
/* clones a triangle object */

   RPIStub long
RPI_drei_clone_dreiobj
   (RPI_HANDLE handle,RPI_OBJECT obj,char *desired_name,RPI_OBJECT *new_dreiobj);

   /* handle:       refgateway-handle
      obj:          object-handle
      koerper_nr:   krper-number (0..#krper-1)
      desired_name: desired name for new triangle object
      new_dreiobj:  destination for the new triangle objekt handle
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* texture-uv-functions */
/* asks for the texture-uv-mapping-mode of a triangle-object */

   RPIStub long
RPI_drei_get_tex_uv_mode
   (RPI_HANDLE handle,RPI_OBJECT obj,long *mode);

   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      mode:         destination for texture-uv-mode
                    (0= no uv-mapping, 1=uv-mapping)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* set the textur-uv-mapping-mode of a triangle-object */

   RPIStub long
RPI_drei_set_tex_uv_mode
   (RPI_HANDLE handle,RPI_OBJECT obj,long mode);

   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      mode:         texture-uv-mapping-mode
                    (0= no uv-mapping, 1=uv-mapping)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* asks for the texture-uv-mapping-coordinates of a single triangle of a triangle-object */

   RPIStub long
RPI_drei_get_tex_uv_coord
   (RPI_HANDLE handle,RPI_OBJECT obj,long drei_nr,float *uvw_param);

   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      drei_nr:      nr of triangle
      uvw_param:    destination for uvw-params of the vertices of the triangle (9 floats)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* sets the texture-uv-mapping-coordinates of a single triangle of a triangle-object */

   RPIStub long
RPI_drei_set_tex_uv_coord
   (RPI_HANDLE handle,RPI_OBJECT obj,long drei_nr,float *uvw_param);

   /* handle:       refgateway-handle
      obj:          object-handle of triangle-object
      drei_nr:      nr of triangle
      uvw_param:    the uvw-params of the vertices of the triangle (9 floats)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#endif /* if MONZOOM_VERSION >= 45 */
/*****************************************************************************/
