/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    file functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  27.3.98 by RG */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
/* open a file requester and let user select a single file */

   RPIStub long
RPI_request_file
   (RPI_HANDLE handle,char *title,char *default_dir,char *default_name,char *filename);

   /* handle:      refgateway-handle
      title :      requester title
      default_dir  default directory or NULL
      default_name default file(s) (including wildcards) or NULL
      filename:    ptr to buffer for selected filename
      returns:     0 if user canceled requester
                   1 if user has selected a file
   */
/*****************************************************************************/
/* open a file for reading (binary mode) */

   RPIStub RPI_FILE
RPI_file_open_read_binary
   (RPI_HANDLE handle,long mode,char *filename);

   /* handle:      refgateway-handle
      mode:        flag to determine the byte order
                      0:  ignore byte order
                      1:  motorola byte order
                      2:  intel byte order
      filename:    name of file to open
      returns:     0 if failed
                   file_pointer if ok
   */
/*****************************************************************************/
/* open a file for writing (binary mode) */

   RPIStub RPI_FILE
RPI_file_open_write_binary
   (RPI_HANDLE handle,long mode,char *filename);

   /* handle:      refgateway-handle
      filename:    name of file to open
      returns:     0 if failed
                   file_pointer if ok
   */
/*****************************************************************************/
/* open a file for reading (text mode) */

   RPIStub RPI_FILE
RPI_file_open_read_text
   (RPI_HANDLE handle,char *filename);

   /* handle:      refgateway-handle
      filename:    name of file to open
      returns:     0 if failed
                   file_pointer if ok
   */
/*****************************************************************************/
/* open a file for writing (text mode) */

   RPIStub RPI_FILE
RPI_file_open_write_text
   (RPI_HANDLE handle,char *filename);

   /* handle:      refgateway-handle
      filename:    name of file to open
      returns:     0 if failed
                   file_pointer if ok
   */
/*****************************************************************************/
/* set the byte order of an open binary file */

   RPIStub long
RPI_file_set_mode
   (RPI_FILE file,long mode);

   /* file:        file-handle (returned by RPI_file_open)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read n bytes from file */

   RPIStub long
RPI_file_read_binary
   (RPI_FILE file,void *buffer,long nbytes);

   /* file:        file-handle (returned by RPI_file_open)
      buffer:      ptr to destination buffer
      nbytes:      nr of bytes to read
      returns:     0 if failed
                   nr of readed bytes if ok
   */
/*****************************************************************************/
/* write n bytes to file */

   RPIStub long
RPI_file_write_binary
   (RPI_FILE file,void *buffer,long nbytes);

   /* file:        file-handle (returned by RPI_file_open)
      buffer:      ptr to source buffer
      nbytes:      nr of bytes to write
      returns:     0 if failed
                   nr of written bytes if ok
   */
/*****************************************************************************/
/* read a string from a text-file */

   RPIStub long
RPI_file_read_string
   (RPI_FILE file,char *buffer,long maxbytes);

   /* file:        file-handle (returned by RPI_file_open_text)
      buffer:      ptr to destination buffer
      maxbytes:    maximum nr of bytes to read into the buffer
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write string to a text-file */

   RPIStub long
RPI_file_write_string
   (RPI_FILE file,char *buffer);

   /* file:        file-handle (returned by RPI_file_open_text)
      buffer:      ptr to string
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write a single short integer to file */

   RPIStub long
RPI_file_write_short
   (RPI_FILE file,short value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       short int to be stored
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write an array of short integers to file */

   RPIStub long
RPI_file_write_shorts
   (RPI_FILE file,short *values,long count);

   /* file:        file-handle (returned by RPI_file_open)
      values:      source array of short ints
      count:       nr of short ints to write
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write a single long integer to file */

   RPIStub long
RPI_file_write_long
   (RPI_FILE file,long value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       long int to be stored
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write an array of long integers to file */

   RPIStub long
RPI_file_write_longs
   (RPI_FILE file,long *values,long count);

   /* file:        file-handle (returned by RPI_file_open)
      values:      source array of long ints
      count:       nr of long ints to write
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write a single float to file */

   RPIStub long
RPI_file_write_float
   (RPI_FILE file,float value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       float to be stored
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write an array of floats to file */

   RPIStub long
RPI_file_write_floats
   (RPI_FILE file,float *values,long count);

   /* file:        file-handle (returned by RPI_file_open)
      values:      source array of floats
      count:       nr of floats to write
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write a single double to file */

   RPIStub long
RPI_file_write_double
   (RPI_FILE file,double value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       double to be stored
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read a single short integer from file */

   RPIStub long
RPI_file_read_short
   (RPI_FILE file,short *value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       ptr to short int to be readed
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read an array of short integers from file */

   RPIStub long
RPI_file_read_shorts
   (RPI_FILE file,short *values,long count);

   /* file:        file-handle (returned by RPI_file_open)
      values:      destination array of short ints
      count:       nr of short ints to read
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read a single long integer from file */

   RPIStub long
RPI_file_read_long
   (RPI_FILE file,long *value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       ptr to long int to be readed
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read an array of long integers from file */

   RPIStub long
RPI_file_read_longs
   (RPI_FILE file,long *values,long count);

   /* file:        file-handle (returned by RPI_file_open)
      values:      destination array of long ints
      count:       nr of long ints to read
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read a single float from file */

   RPIStub long
RPI_file_read_float
   (RPI_FILE file,float *value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       ptr to long int to be readed
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read an array of floats from file */

   RPIStub long
RPI_file_read_floats
   (RPI_FILE file,float *values,long count);

   /* file:        file-handle (returned by RPI_file_open)
      values:      destination array of floats
      count:       nr of floats to read
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read a single double from file */

   RPIStub long
RPI_file_read_double
   (RPI_FILE file,double *value);

   /* file:        file-handle (returned by RPI_file_open)
      value:       ptr to double to be readed
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the current absolute position of file */

   RPIStub long
RPI_file_set_pos
   (RPI_FILE file,long pos);

   /* file:        file-handle (returned by RPI_file_open)
      pos:         new position in file (absolute value)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the current absolute position of file */

   RPIStub long
RPI_file_get_pos
   (RPI_FILE file,long *pos);

   /* file:        file-handle (returned by RPI_file_open)
      pos:         destination for file position (absolute value)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* set the position of file relative to the current position */

   RPIStub long
RPI_file_set_pos_relative
   (RPI_FILE file,long pos);

   /* file:        file-handle (returned by RPI_file_open)
      pos:         new file position (relative to current position)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* get the length of file */

   RPIStub long
RPI_file_length
   (RPI_FILE file,long *len);

   /* file:        file-handle (returned by RPI_file_open)
      len:         destination for file length (in bytes)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* close file opened with RPI_open_file */

   RPIStub long
RPI_file_close
   (RPI_FILE file);

   /* file:        file-handle (returned by RPI_file_open)
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* test for existence of a file */

   RPIStub long
RPI_file_exist
   (RPI_HANDLE handle,char *filename);

   /* handle:      refgateway-handle
      filename:    name of file to test for existence
      returns:     0 if file not exists
                   1 if file exists
   */
/*****************************************************************************/
/* tell reflection to send PLI_LOAD_SCENE messages */

   RPIStub long
RPI_add_scene_loader
   (RPI_HANDLE handle);

   /* handle:      refgateway-handle
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* tell reflection to send PLI_LOAD_SCENE messages */
/* extended version with optional filename suffixes for the file requester */

   RPIStub long
RPI_add_scene_loader_ext
   (RPI_HANDLE handle,long n_entries,char **suffixes,char **descriptions);

   /* handle:       refgateway-handle
      n_entries:    number of entries in the suffixes array
      suffixes:     array with n_entries suffix strings
      descriptions: array with n_entries file type description strings
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#if MONZOOM_VERSION >= 45
/*****************************************************************************/
/* tell reflection to send PLI_SAVE_SCENE messages */
/* filename suffixes for the file requester */

   RPIStub long
RPI_add_scene_saver
   (RPI_HANDLE handle,long n_entries,char **suffixes,char **descriptions);

   /* handle:       refgateway-handle
      n_entries:    number of entries in the suffixes array
      suffixes:     array with n_entries suffix strings
      descriptions: array with n_entries file type description strings
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#endif /* if MONZOOM_VERSION >= 45 */
/*****************************************************************************/
/* write objects as ref-szene-file */

   RPIStub long
RPI_write_objects
   (RPI_HANDLE handle,char *filename,long n_objects,RPI_OBJECT *objects,
   long with_needed,char *err_msg);

   /* handle:      refgateway-handle
      filename:    filename to write objects to. (reflections automatically
                   adds actual suffix)
      n_objects:   nr of objects in the objects-array to write
      objects:     array of <n_objects> pointer to ref-objects
      with_needed: flag: 0 : ref only writes objects objects-array
                         1 : ref scans all other objects which may be needed from
                             the objects in the array and saves them also
                             (e.g. materials of geo-objs)
      err_msg:     buffer for an error-string if something failed.
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* write whole scene as ref-szene file */

   RPIStub long
RPI_write_szene
   (RPI_HANDLE handle,char *filename,char *err_msg);

   /* handle:      refgateway-handle
      filename:    filename to write objects to. (reflections automatically
                   adds actual suffix)
      err_msg:     buffer for an error-string if something failed.
      returns:     0 if failed
                   1 if ok
   */
/*****************************************************************************/
/* read a scene file */

   RPIStub long
RPI_read_szene
   (RPI_HANDLE handle,char *filename,char *err_msg);

   /* handle:      refgateway-handle
      filename:    filename of scene
      err_msg:     buffer for an error-string if something failed.
      returns:     0 if failed
                   number of readed objects if ok
   */
/*****************************************************************************/
/* install a picture loader/saver module */

   RPIStub long
RPI_add_pic_loader_saver
   (RPI_HANDLE handle,long n_entries,char **suffixes,char **descriptions);

   /* handle:       refgateway-handle
      n_entries:    number of entries in the suffixes array
      suffixes:     array with n_entries suffix strings
      descriptions: array with n_entries file type description strings
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
