/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/

/* title:    user interface functions for geo-objects */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  15.9.98 by CF */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */

/*****************************************************************************/
/* add a tool to the reflections x-tra menu */

   RPIStub long 
RPI_geo_edit_add_tool
   (RPI_HANDLE handle,char *bildfile,char *bildfile_sel,long tool_id,long geo_id)
{
   /* handle:       refgateway-handle
      bildfile:     filename of the icon image, normal state
      bildfile_sel: filename of the icon image, selected state
      tool_id:      unique id, used to identify the tool
      geo_id:       reflections object type the tool is made for
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_ADD_TOOL;
   in.s_param[0]=bildfile;
   in.s_param[1]=bildfile_sel;
   in.l_param[0]=tool_id;
   in.l_param[1]=geo_id;
   return(RPI_do(&in,&out));   
}
/*****************************************************************************/
/* remove a tool from the reflections x-tra menu */

   RPIStub long
RPI_geo_edit_sub_tool
   (RPI_HANDLE handle,long tool_id)
{
   /* handle:       refgateway-handle
      tool_id:      unique id, used to identify the tool
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_SUB_TOOL;
   in.l_param[0]=tool_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* add a interactive tool to reflections x-tra menu */

   RPIStub long
RPI_geo_edit_add_interactive_tool
   (RPI_HANDLE handle,char *bildfile,char *bildfile_sel,long tool_id,long geo_id)
{
   /* handle:       refgateway-handle
      bildfile:     filename of the icon image, normal state
      bildfile_sel: filename of the icon image, selected state
      tool_id:      unique id, used to identify the tool
      geo_id:       reflections object type the tool is made for
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_ADD_INTERACTIVE_TOOL;
   in.s_param[0]=bildfile;
   in.s_param[1]=bildfile_sel;
   in.l_param[0]=tool_id;
   in.l_param[1]=geo_id;
   return(RPI_do(&in,&out));   
}
/*****************************************************************************/
/* request messages for geo-editor events */

   RPIStub long 
RPI_geo_edit_inform
   (RPI_HANDLE handle,unsigned long flags)
{
   /* handle:       refgateway-handle
      flags:        bitfield that specifies the events the plug wants
                    to be informed about. defined in rgw_defs.h.
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_INFORM;
   in.l_param[0]=flags;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the currently selected object */

   RPIStub long
RPI_geo_edit_get_selected_obj
   (RPI_HANDLE handle,RPI_OBJECT *obj)
{
   /* handle:       refgateway-handle
      obj:          destination for object-handle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_GET_SELECTED_OBJ;
   if (0!=(ret=RPI_do(&in,&out)))
     *obj=out.v_param[0];
   return(ret);
}
/*****************************************************************************/
/* switch into the pt-editor (including xtra-menu) for a geo-objekt */

   RPIStub long
RPI_geo_edit_pkt_editor
   (RPI_HANDLE handle,RPI_OBJECT obj)
{
   /* handle:       refgateway-handle
      obj:          object-handle for geo-object to switch to the pt-editor
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_PKT_EDITOR;
   in.v_param[1]=obj;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* press a button in the xtra-menu of the pt-editor */

   RPIStub long
RPI_geo_edit_press_xtra_button
   (RPI_HANDLE handle,long tool_id)
{
   /* handle:       refgateway-handle
      tool_id:      tool_id, which was used to install the xtra-tool
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_PRESS_XTRA_BUTTON;
   in.l_param[0]=tool_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* release a pressed-button in the xtra-menu of the pt-editor */

   RPIStub long
RPI_geo_edit_release_xtra_button
   (RPI_HANDLE handle,long tool_id)
{
   /* handle:       refgateway-handle
      tool_id:      tool_id, which was used to install the xtra-tool
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_GEO_EDIT_RELEASE_XTRA_BUTTON;
   in.l_param[0]=tool_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
