/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    user interface functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 15.12.97 */
/* updated:  17.9.98 by RG */
/* version:  1.1,  */
/* updated:  17.9.98 */
/* updated:  16.11.99 by RG */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
#include <string.h>
/*****************************************************************************/
/* request numerical informations from reflections */

   RPIStub long
RPI_get_ref_info
   (RPI_HANDLE handle,long info_art,long *wert);

   /* handle:       refgateway-handle
      info_art:     type of requested information. defined in rgw_defs.h
      wert:         destination for the requested long int value
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request text informations from reflections */

   RPIStub long
RPI_get_ref_char_info
   (RPI_HANDLE handle,long info_art,char *wert);

   /* handle:       refgateway-handle
      info_art:     type of requested information. defined in rgw_defs.h
      wert:         destination for the requested char string
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let reflections unload the plugin. we receive a RPI_CLOSE_RESOURCES */
/* message before we get killed... */

   RPIStub long
RPI_free_myself
   (RPI_HANDLE handle);

   /* handle:       refgateway-handle
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get the error code of the last error */

   RPIStub long
RPI_get_last_err
   (RPI_HANDLE handle,long *error_code);

   /* handle:       refgateway-handle
      error_code:   destination for the error code
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request timer messages from reflections */

   RPIStub long
RPI_set_timer
   (RPI_HANDLE handle,float seconds);

   /* handle:       refgateway-handle
      seconds:      delay_time (seconds to wait to next timer-message)
      returns:      0 if failed
                    1 if ok, reflections will send PLI_TIMER-messages
   */
/*****************************************************************************/
/* cancel the request for timer messages */

   RPIStub long
RPI_kill_timer
   (RPI_HANDLE handle);

   /* handle:       refgateway-handle
      returns:      0 if failed
                    1 if ok, no more PLI_TIMER-messages will be sent
   */
/*****************************************************************************/
/* let reflections create a button menu window for us */

   RPIStub long
RPI_make_button_win
   (RPI_HANDLE handle,char *titel,long n_buttons,
    char **text_tab,long x,long y,long *win_id);

   /* handle:       refgateway-handle
      title:        title of button window
      n_buttons:    number of text buttons
      text_tab:     table of <n_buttons> pointers to c-strings
      x,y:          desired position for window
      win_id:       destination for ID_number of new button window
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let reflections close a button menu window */

   RPIStub long
RPI_close_button_win
   (RPI_HANDLE handle,long win_id,long *last_x,long *last_y);

   /* handle:        refgateway-handle
      win_id:        ID_number of button window as returned
                     by RPI_make_button_win()
      last_x,last_y: destination for position of window when closed
      returns:       0 if failed
                     1 if ok
   */
/*****************************************************************************/
/* press a button of a button window */

   RPIStub long
RPI_press_button
   (RPI_HANDLE handle,long win_id,long button_nr);

   /* handle:       refgateway-handle
      win_id:       ID_number of the button window
      button_nr:    number of the button to press, starting at 0
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* release a button of a button window */

   RPIStub long
RPI_release_button
   (RPI_HANDLE handle,long win_id,long button_nr);

   /* handle:       refgateway-handle
      win_id:       ID_number of the button window
      button_nr:    number of the button to release, starting at 0
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let reflections display a message for us */

   RPIStub long
RPI_message_win
   (RPI_HANDLE handle,char *text);

   /* handle:       refgateway-handle
      text:         text to display in the message window
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let reflections display an yes/no requester */

   RPIStub long
RPI_ask_win
   (RPI_HANDLE handle,char *text,long *yes_no);

   /* handle:       refgateway-handle
      text:         text to display in the requester window
      yes_no:       destination for the users decision
                    1 if user chooses yes, 0 if user chooses no
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* display a message in reflections main window's status line */

   RPIStub long
RPI_print
   (RPI_HANDLE handle,char *text);

   /* handle:       refgateway-handle
      text:         text to display in the status line
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let the user select 1 of n options in a button menu window and return */

   RPIStub long
RPI_get_selection
   (RPI_HANDLE handle,char *text,long n_sel,char **text_tab,long *selected);

   /* handle:       refgateway-handle
      text:         text to display in the selection window
      n_sel:        number of selections
      text_tab:     table of <n_sel> pointers to c-strings
      selected:     destination for the users selections
                    -1 if user canceled, 0..<n_sel>-1 selection of user
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let the user choose m of n options in a button menu window and return */

   RPIStub long
RPI_get_multi_selection
   (RPI_HANDLE handle,char *text,long n_sel,char **text_tab,
    long *n_selected,long *selections,long max_selections);

   /* handle:         refgateway-handle
      text:           text to display in the selection window
      n_sel:          number of selections
      text_tab:       table of <n_sel> pointers to c-strings
      n_selected      destination for the number of selected items
                      0 if user canceled
      selections      destination array of long ints for the selection
      max_selections: how many selections can be stored in selections
      returns:        0 if failed
                      1 if ok
   */
/*****************************************************************************/
/* let the user set a flag, wether the items in following-selection-requesters
   of the plugin should be sorted alphabetically or not */

   RPIStub void
RPI_set_selection_sort_flag
   (RPI_HANDLE handle,long sort);

   /* handle:       refgateway-handle
      sort:         flag for succeeding calls to selection-requesters
      returns:      nothing
   */
/*****************************************************************************/
/* let reflections execute an external skript command */

   RPIStub long
RPI_do_skript_command
   (RPI_HANDLE handle,char *command,char *result,char *err);

   /* handle:       refgateway-handle
      command:      filename of the skript command
      result:       destination buffer for the result
      err:          ptr to error message that reflections displays
                    when an error occurs
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request a string from user */

   RPIStub long
RPI_get_string
   (RPI_HANDLE handle,char *frage,char *defaul,char *wert,long *ok);

   /* handle:       refgateway-handle
      frage:        text to display in the string requester
      defaul:       default string
      wert:         destination for the requested string
      ok:           destination for the requester state
                    0=user canceled requester, 1=user entered string
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request a long int value from user */

   RPIStub long
RPI_get_int
   (RPI_HANDLE handle,char *frage,long defaul,long *wert,long *ok);

   /* handle:       refgateway-handle
      frage:        text to display in the requester
      defaul:       default value
      wert:         destination for the requested long int
      ok:           destination for the requester state
                    0=user canceled requester, 1=user entered a value
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request a number of integer values from user */

   RPIStub long
RPI_get_n_ints
   (RPI_HANDLE handle,char *frage,long n_ints,long *werte,char **var_namen,long *ok);

   /* handle:       refgateway-handle
      frage:        title to display in the requester
      n_ints:       nr of integer values
      werte:        destination for the requested integers
      var_namen:    names of the integer variables
      ok:           destination for the requester state
                    0=user canceled requester, 1=user entered values
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request a float value from user */

   RPIStub long
RPI_get_real
   (RPI_HANDLE handle,char *frage,float defaul,float *wert,long *ok);

   /* handle:       refgateway-handle
      frage:        text to display in the requester
      defaul:       default value
      wert:         destination for the requested float
      ok:           destination for the requester state
                    0=user canceled requester, 1=user entered a value
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* request a number of float values from user */

   RPIStub long
RPI_get_n_reals
   (RPI_HANDLE handle,char *frage,long n_floats,float *werte,char **var_namen,long *ok);

   /* handle:       refgateway-handle
      frage:        title to display in the requester
      n_floats      nr of float values
      werte:        destination for the requested floats
      var_namen:    names of the float variables
      ok:           destination for the requester state
                    0=user canceled requester, 1=user entered values
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let the user define a requester (modal or nonmodal) */

   RPIStub long
RPI_define_requester
   (RPI_HANDLE handle,
    char *text,
    long id,
    long xpos,long ypos,
    long n_items,
    long modal,
    char **text_tab,
    long *code_tab,
    void **var_tab,
    float *minmax_tab);

   /* handle:       refgateway-handle
      text:         text to display in the requester
      id:           ID-number, which is send in messages for this requester
      xpos,ypos:    prefered position of requester (xpos=-1 -> position of cursor)
      n_items:      number of input items
      modal:        flag: 0=nonmodal, 1=modal
      text_tab:     table of <n_items> pointers to c-strings
      code_tab      table of longs to describe the <n_items> input-elements
      var_tab:      table of void pointers pointing to the variables of the input-items
      minmax_tab    table of floats defining the minimum and maximum values
                    for sliders with the CODE_INT_EXTENDED and
                    CODE_REAL_EXTENDED elements only
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* close a requester, modal or nonmodal */
#define RPI_close_modal_requester RPI_close_requester
#define RPI_close_nonmodal_requester RPI_close_requester

   RPIStub long
RPI_close_requester
   (RPI_HANDLE handle,long id);

   /* handle:       refgateway-handle
      id:           ID-number of nonmodal-requester
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let the user define a nonmodal requester */

   RPIStub long
RPI_define_nonmodal_requester
   (RPI_HANDLE handle,
    char *text,
    long id,
    long xpos,long ypos,
    long n_items,
    char **text_tab,
    long *code_tab,
    void **var_tab,
    float *minmax_tab);
/*****************************************************************************/
/* let the user define a modal requester */

   RPIStub long
RPI_define_modal_requester
   (RPI_HANDLE handle,
    char *text,
    long id,
    long xpos,long ypos,
    long n_items,
    char **text_tab,
    long *code_tab,
    void **var_tab,
    float *minmax_tab);
/*****************************************************************************/
/* let the requester display changed values*/

   RPIStub long
RPI_requester_values_changed
   (RPI_HANDLE handle,long id);

   /* handle:       refgateway-handle
      id:           ID-number of requester
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get a prozent-display */

   RPIStub long
RPI_start_prozent
   (RPI_HANDLE handle,char *text);

   /* handle:       refgateway-handle
      text:         text to display with the prozent-display
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get a optimized prozent-display */

   RPIStub long
RPI_start_prozent1
   (RPI_HANDLE handle,char *text,long *static_var);

   /* handle:       refgateway-handle
      text:         text to display with the prozent-display
      static_var:   static variable (used for speedup)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* set prozent-display */

   RPIStub long
RPI_set_prozent
   (RPI_HANDLE handle,float proz);

   /* handle:       refgateway-handle
      proz:         progress in range 0..1
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* set a optimized prozent-display */

   RPIStub long
RPI_set_prozent1
   (RPI_HANDLE handle,float proz,long *static_var);

   /* handle:       refgateway-handle
      proz:         progress in range 0..1
      static_var:   static variable (used for speedup)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* cancel prozent-display */

   RPIStub long
RPI_stop_prozent
   (RPI_HANDLE handle);

   /* handle:       refgateway-handle
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* show help-text or help-stichwort */

   RPIStub long
RPI_show_help
   (RPI_HANDLE handle,char *item,long as_index);

   /* handle:       refgateway-handle
      item:         text to show or help-index-word
      as_index:     1 to show item, 2 to show help file
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* like RPI_show_help, but also returns an id-nr which can be
   used to close the help_window
*/

   RPIStub long
RPI_show_help1
   (RPI_HANDLE handle,char *item,long as_index,long *id);

   /* handle:       refgateway-handle
      item:         text to show or help-index-word
      as_index:     1 to show item, 2 to show help file
      id:           destination to store the help_window-index
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* close the help-window which was openend with RPI_show_help1
   if the window is already closed, this functions does nothing
*/

   RPIStub long
RPI_close_help
   (RPI_HANDLE handle,long id);

   /* handle:       refgateway-handle
      id:           help_window-index which was returned by RPI_show_help1
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#if MONZOOM_VERSION >= 45
/*****************************************************************************/
/* get the actual position of a requester*/

   RPIStub long
RPI_get_requester_pos
   (RPI_HANDLE handle,long id,long *x,long *y);

   /* handle:       refgateway-handle
      id:           ID-number of requester
      x,y:          destination for the window position
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#endif /* if MONZOOM_VERSION >= 45 */
/*****************************************************************************/
