/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/

/* title:    general object functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  23.3.98 by RG */
/* version:  1.1, 19.7.99 */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */

/*****************************************************************************/
/* create a new object of specified type */

   RPIStub RPI_OBJECT
RPI_obj_new
   (RPI_HANDLE handle,long id,char *name)
{
   /* handle:       refgateway-handle
      id:           type of reflections object to create
      name:         desired name of the new object, may be altered by
                    reflections if an object with that name already exists
      returns:      NULL if failed
                    object-handle if ok
   */
   PLI_param in,out;
   RPI_OBJECT obj=NULL;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_NEW;
   in.l_param[0]=id;
   in.s_param[0]=name;
   if (RPI_do(&in,&out))
     obj=out.v_param[0];
   return(obj);
}
/*****************************************************************************/
/* get the id (type) of an object */

   RPIStub long
RPI_obj_get_id
   (RPI_HANDLE handle,RPI_OBJECT obj)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      returns:      0 if failed
                    ID_number of object if ok
   */
   PLI_param in,out;
   long id=0L;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_GET_ID;
   in.v_param[1]=obj;   
   if (RPI_do(&in,&out))
     id=out.l_param[0];
   return(id);
}
/*****************************************************************************/
/* remove a reflections object */

   RPIStub long
RPI_obj_free
   (RPI_HANDLE handle,RPI_OBJECT obj)
{
   /* handle:       refgateway-handle
      obj:          object-handle of object to delete
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_FREE;
   in.v_param[1]=obj;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* copy the data of obj_from to obj_to */

   RPIStub long
RPI_obj_copy
   (RPI_HANDLE handle,RPI_OBJECT obj_from,RPI_OBJECT obj_to)
{
   /* handle:       refgateway-handle
      obj_from:     source object-handle
      obj_to:       destination object-handle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   
   in.v_param[0]=handle;
   in.id=RPI_OBJ_COPY;
   in.v_param[1]=obj_from;
   in.v_param[2]=obj_to;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* rename a reflections object */

   RPIStub long
RPI_obj_set_name
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      name:         desired new name
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_SET_NAME;
   in.v_param[1]=obj;
   in.s_param[0]=name;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the name of an object */

   RPIStub long
RPI_obj_get_name
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      name:         destination buffer for the name
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
 
   in.v_param[0]=handle;
   in.id=RPI_OBJ_GET_NAME;
   in.v_param[1]=obj;
   out.s_param[0]=name;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* let reflections send us messages when an object is edited */
   
   RPIStub long
RPI_obj_inform
   (RPI_HANDLE handle,unsigned long bitmask)
{
   /* handle:       refgateway-handle
      bitmask:      the inform flags bitwise ored together
                    bits defined in rgw_defs.h
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_INFORM;
   in.l_param[0]=(long)bitmask;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the class name for an object */

   RPIStub long
RPI_obj_get_class_name
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      name:         destination for the name of the object-class of the object
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_GET_CLASS_NAME;
   in.v_param[1]=obj;
   out.s_param[0]=name;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* ask reflections if the class of obj1 is a subclass of the class of obj2 */

   RPIStub long
RPI_obj_is_sub_class_of
   (RPI_HANDLE handle,RPI_OBJECT obj1,RPI_OBJECT obj2,long *is_sub)
{
   /* handle:       refgateway-handle
      obj1,obj2:    object-handles
      is_sub:       destination for the requested information
                    0=not a subclass
                    1=the class of obj1 is a subclass of the class of obj2
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_IS_SUB_CLASS_OF;
   in.v_param[1]=obj1;
   in.v_param[2]=obj2;
   if (0!=(ret=RPI_do(&in,&out)))
     *is_sub=out.l_param[0];
   return(ret);
}
/*****************************************************************************/

#if MONZOOM_VERSION >= 45

/*****************************************************************************/
/* ask reflections if the class of obj1 is a subclass of the given obj_id */

   RPIStub long
RPI_obj_is_sub_class_of1
   (RPI_HANDLE handle,RPI_OBJECT object,long obj_id,long *is_sub)
{
   /* handle:       refgateway-handle
      object:       object-handle
      obj_id:       object id
      is_sub:       destination for the requested information
                    0=not a subclass
                    1=the class of object is a subclass of the class of obj_id
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_IS_SUB_CLASS_OF1;
   in.v_param[1]=object;
   in.l_param[0]=obj_id;
   if (0!=(ret=RPI_do(&in,&out)))
     *is_sub=out.l_param[0];
   return(ret);
}
/*****************************************************************************/

#endif /* if MONZOOM_VERSION >= 45 */

/*****************************************************************************/
/* forbid editing of an object and/or its points */

   RPIStub long
RPI_obj_lock
   (RPI_HANDLE handle,RPI_OBJECT obj,unsigned long bitmask,long *is_locked)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      bitmask:      the rights flags bitwise ored together
                    defined in rgw_defs.h
      is_locked:    destination for the success of locking attempt
                    0 if you cant get the lock (because anotherone has the lock)    
                    1 if you get the lock for the rights
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_LOCK;
   in.v_param[1]=obj;
   in.l_param[0]=bitmask;
   if (0!=(ret=RPI_do(&in,&out)))
      *is_locked=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* release all object locks */

   RPIStub long
RPI_obj_unlock
   (RPI_HANDLE handle,RPI_OBJECT obj,long *is_unlocked)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      is_unlocked:  destination for the success of unlocking attempt
                    0 if you cant unlock it because anotherone has locked it
                    1 if the object is know unlocked
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_UNLOCK;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
     *is_unlocked=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* ask reflections if specified locks are available */

   RPIStub long
RPI_obj_allowed
   (RPI_HANDLE handle,RPI_OBJECT obj,unsigned long bitmask,long *is_allowed)
{
   /* handle:       refgateway-handle
      obj:          object-handle
      bitmask:      the rights flags bitwise ored together
                    defined in rgw_defs.h
      is_allowed:   destination for the result
                    0 if someone else owns the requested locks    
                    1 if the locks for the requested rights are available
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_ALLOWED;
   in.v_param[1]=obj;
   in.l_param[0]=bitmask;
   if (0!=(ret=RPI_do(&in,&out)))
      *is_allowed=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* find a object by name and return object ptr */

   RPIStub RPI_OBJECT
RPI_find_obj
   (RPI_HANDLE handle,char *name)
{
   /* handle:       refgateway-handle
      name:         name of the object to search for
      returns:      NULL if failed
                    object ptr if ok
   */
   PLI_param in,out;
   RPI_OBJECT obj=NULL;

   in.v_param[0]=handle;
   in.id=RPI_FIND_OBJ;
   in.s_param[0]=name;
   if (RPI_do(&in,&out))
     obj=out.v_param[0];
   return(obj);
}
/*****************************************************************************/
/* find the number of objects of a specific id */

   RPIStub long
RPI_n_objs
   (RPI_HANDLE handle,long id,long use_subclasses)
{
   /* handle:          refgateway-handle
      id:              object-id
      uses_subclasses: flag to include subclasses in search
                       0=find only objects with id
                       1=find also subclasses of id
      returns:         number of found objects
   */
   PLI_param in,out;
   long n=0L;

   in.v_param[0]=handle;
   in.id=RPI_N_OBJS;
   in.l_param[0]=id;
   in.l_param[1]=use_subclasses;
   if (RPI_do(&in,&out))
     n=out.l_param[0];
   return(n);
}
/*****************************************************************************/
/* get objects of a specific id */

   RPIStub long
RPI_get_objs
   (RPI_HANDLE handle,long id,long use_subclasses,long maxobj,RPI_OBJECT *array)
{
   /* handle:          refgateway-handle
      id:              object-id
      uses_subclasses: flag to include subclasses in search
                       0=find only objects with id
                       1=find also subclasses of id
      returns:         number of stored objects
   */
   PLI_param in,out;
   long n=0L;

   in.v_param[0]=handle;
   in.id=RPI_GET_OBJS;
   in.v_param[1]=(void *)array;
   in.l_param[0]=id;
   in.l_param[1]=use_subclasses;
   in.l_param[2]=maxobj;
   if (RPI_do(&in,&out))
     n=out.l_param[0];
   return(n);
}
/*****************************************************************************/
/* set a variable of an object */

   RPIStub long
RPI_obj_set_var
   (RPI_HANDLE handle,RPI_OBJECT obj,long nr,float wert)
{
   /* handle:          refgateway-handle
      nr:              nr of variable
      wert:            value to set
      returns:         0 if failed
                       1 if success
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_SET_VAR;
   in.v_param[1]=obj;
   in.l_param[0]=nr;
   in.f_param[0]=wert;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get a variable of an object */

   RPIStub long
RPI_obj_get_var
   (RPI_HANDLE handle,RPI_OBJECT obj,long nr,float *wert)
{
   /* handle:          refgateway-handle
      nr:              nr of variable
      wert:            destination for variable value
      returns:         0 if failed
                       1 if success
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_GET_VAR;
   in.v_param[1]=obj;
   in.l_param[0]=nr;
   if (0!=(ret=RPI_do(&in,&out)))
     *wert=out.f_param[0];
   return(ret);
}
/*****************************************************************************/
/* get nr of variables of an object */

   RPIStub long
RPI_obj_get_nvars
   (RPI_HANDLE handle,RPI_OBJECT obj,long *nvars)
{
   /* handle:          refgateway-handle
      nvars:           destination of nr of variables
      returns:         0 if failed
                       1 if success
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_GET_NVARS;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
     *nvars=out.l_param[0];
   return(ret);
}
/*****************************************************************************/

#if MONZOOM_VERSION >= 45

/*****************************************************************************/
/* connect an object to a custom_data-record */

   RPIStub long
RPI_obj_connect_custom_data
   (RPI_HANDLE handle,RPI_OBJECT obj,char *custom_data_id,void *custom_data)
{
   /* handle:           refgateway-handle
      obj:              object-handle
      custom_data_id:   string, which is an identifier for the custom_data   
      custom_data:      pointer to the custom_data
      returns:          0 if failed
                        1 if success
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_CONNECT_CUSTOM_DATA;
   in.v_param[1]=obj;
   in.v_param[2]=custom_data;
   in.s_param[0]=custom_data_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* disconnect an object from a custom_data-record */

   RPIStub long
RPI_obj_disconnect_custom_data
   (RPI_HANDLE handle,RPI_OBJECT obj,char *custom_data_id)
{
   /* handle:           refgateway-handle
      obj:              object-handle
      custom_data_id:   string, which is an identifier for the custom_data   
      returns:          0 if failed
                        1 if success
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_DISCONNECT_CUSTOM_DATA;
   in.v_param[1]=obj;
   in.s_param[0]=custom_data_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* ask for the custom_data of an object */

   RPIStub long
RPI_obj_get_custom_data
   (RPI_HANDLE handle,RPI_OBJECT obj,char *custom_data_id,void **custom_data)
{
   /* handle:           refgateway-handle
      obj:              object-handle
      custom_data_id:   string, which is an identifier for the custom_data   
      returns:          0 if failed
                        1 if success
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_OBJ_GET_CUSTOM_DATA;
   in.v_param[1]=obj;
   in.s_param[0]=custom_data_id;
   if (0!=(ret=RPI_do(&in,&out)))
     *custom_data=out.v_param[0];  
   return(ret);
}
/*****************************************************************************/
/* add a loader/saver for a custom_data_id */
   
   RPIStub long
RPI_add_custom_data_load_save
   (RPI_HANDLE handle,char *custom_data_id)
{
   /* handle:           refgateway-handle
      custom_data_id:   string, which is an identifier for the custom_data   
      returns:          0 if failed
                        1 if success
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_ADD_CUSTOM_DATA_LOAD_SAVE;
   in.s_param[0]=custom_data_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* sub a loader/saver for a custom_data_id */

   RPIStub long
RPI_sub_custom_data_load_save
   (RPI_HANDLE handle,char *custom_data_id)
{
   /* handle:           refgateway-handle
      custom_data_id    string, which is an identifier for the custom_data   
      returns:          0 if failed
                        1 if success
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_SUB_CUSTOM_DATA_LOAD_SAVE;
   in.s_param[0]=custom_data_id;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/

#endif /* MONZOOM_VERSION >= 45 */

/*****************************************************************************/
