/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    general object functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  23.3.98 by RG */
/* version:  1.1, 19.7.99 */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
/* create a new object of specified type */

   RPIStub RPI_OBJECT
RPI_obj_new
   (RPI_HANDLE handle,long id,char *name);

   /* handle:       refgateway-handle
      id:           type of reflections object to create
      name:         desired name of the new object, may be altered by
                    reflections if an object with that name already exists
      returns:      NULL if failed
                    object-handle if ok
   */
/*****************************************************************************/
/* get the id (type) of an object */

   RPIStub long
RPI_obj_get_id
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:       refgateway-handle
      obj:          object-handle
      returns:      0 if failed
                    ID_number of object if ok
   */
/*****************************************************************************/
/* remove a reflections object */

   RPIStub long
RPI_obj_free
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:       refgateway-handle
      obj:          object-handle of object to delete
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* copy the data of obj_from to obj_to */

   RPIStub long
RPI_obj_copy
   (RPI_HANDLE handle,RPI_OBJECT obj_from,RPI_OBJECT obj_to);

   /* handle:       refgateway-handle
      obj_from:     source object-handle
      obj_to:       destination object-handle
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* rename a reflections object */

   RPIStub long
RPI_obj_set_name
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name);

   /* handle:       refgateway-handle
      obj:          object-handle
      name:         desired new name
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get the name of an object */

   RPIStub long
RPI_obj_get_name
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name);

   /* handle:       refgateway-handle
      obj:          object-handle
      name:         destination buffer for the name
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* let reflections send us messages when an object is edited */

   RPIStub long
RPI_obj_inform
   (RPI_HANDLE handle,unsigned long bitmask);

   /* handle:       refgateway-handle
      bitmask:      the inform flags bitwise ored together
                    bits defined in rgw_defs.h
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get the class name for an object */

   RPIStub long
RPI_obj_get_class_name
   (RPI_HANDLE handle,RPI_OBJECT obj,char *name);

   /* handle:       refgateway-handle
      obj:          object-handle
      name:         destination for the name of the object-class of the object
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* ask reflections if the class of obj1 is a subclass of the class of obj2 */

   RPIStub long
RPI_obj_is_sub_class_of
   (RPI_HANDLE handle,RPI_OBJECT obj1,RPI_OBJECT obj2,long *is_sub);

   /* handle:       refgateway-handle
      obj1,obj2:    object-handles
      is_sub:       destination for the requested information
                    0=not a subclass
                    1=the class of obj1 is a subclass of the class of obj2
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#if MONZOOM_VERSION >= 45
/*****************************************************************************/
/* ask reflections if the class of obj1 is a subclass of the given obj_id */

   RPIStub long
RPI_obj_is_sub_class_of1
   (RPI_HANDLE handle,RPI_OBJECT object,long obj_id,long *is_sub);

   /* handle:       refgateway-handle
      object:       object-handle
      obj_id:       object id
      is_sub:       destination for the requested information
                    0=not a subclass
                    1=the class of object is a subclass of the class of obj_id
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
#endif /* if MONZOOM_VERSION >= 45 */
/*****************************************************************************/
/* forbid editing of an object and/or its points */

   RPIStub long
RPI_obj_lock
   (RPI_HANDLE handle,RPI_OBJECT obj,unsigned long bitmask,long *is_locked);

   /* handle:       refgateway-handle
      obj:          object-handle
      bitmask:      the rights flags bitwise ored together
                    defined in rgw_defs.h
      is_locked:    destination for the success of locking attempt
                    0 if you cant get the lock (because anotherone has the lock)
                    1 if you get the lock for the rights
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* release all object locks */

   RPIStub long
RPI_obj_unlock
   (RPI_HANDLE handle,RPI_OBJECT obj,long *is_unlocked);

   /* handle:       refgateway-handle
      obj:          object-handle
      is_unlocked:  destination for the success of unlocking attempt
                    0 if you cant unlock it because anotherone has locked it
                    1 if the object is know unlocked
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* ask reflections if specified locks are available */

   RPIStub long
RPI_obj_allowed
   (RPI_HANDLE handle,RPI_OBJECT obj,unsigned long bitmask,long *is_allowed);

   /* handle:       refgateway-handle
      obj:          object-handle
      bitmask:      the rights flags bitwise ored together
                    defined in rgw_defs.h
      is_allowed:   destination for the result
                    0 if someone else owns the requested locks
                    1 if the locks for the requested rights are available
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* find a object by name and return object ptr */

   RPIStub RPI_OBJECT
RPI_find_obj
   (RPI_HANDLE handle,char *name);

   /* handle:       refgateway-handle
      name:         name of the object to search for
      returns:      NULL if failed
                    object ptr if ok
   */
/*****************************************************************************/
/* find the number of objects of a specific id */

   RPIStub long
RPI_n_objs
   (RPI_HANDLE handle,long id,long use_subclasses);

   /* handle:          refgateway-handle
      id:              object-id
      uses_subclasses: flag to include subclasses in search
                       0=find only objects with id
                       1=find also subclasses of id
      returns:         number of found objects
   */
/*****************************************************************************/
/* get objects of a specific id */

   RPIStub long
RPI_get_objs
   (RPI_HANDLE handle,long id,long use_subclasses,long maxobj,RPI_OBJECT *array);

   /* handle:          refgateway-handle
      id:              object-id
      uses_subclasses: flag to include subclasses in search
                       0=find only objects with id
                       1=find also subclasses of id
      returns:         number of stored objects
   */
/*****************************************************************************/
/* set a variable of an object */

   RPIStub long
RPI_obj_set_var
   (RPI_HANDLE handle,RPI_OBJECT obj,long nr,float wert);

   /* handle:          refgateway-handle
      nr:              nr of variable
      wert:            value to set
      returns:         0 if failed
                       1 if success
   */
/*****************************************************************************/
/* get a variable of an object */

   RPIStub long
RPI_obj_get_var
   (RPI_HANDLE handle,RPI_OBJECT obj,long nr,float *wert);

   /* handle:          refgateway-handle
      nr:              nr of variable
      wert:            destination for variable value
      returns:         0 if failed
                       1 if success
   */
/*****************************************************************************/
/* get nr of variables of an object */

   RPIStub long
RPI_obj_get_nvars
   (RPI_HANDLE handle,RPI_OBJECT obj,long *nvars);

   /* handle:          refgateway-handle
      nvars:           destination of nr of variables
      returns:         0 if failed
                       1 if success
   */
/*****************************************************************************/
#if MONZOOM_VERSION >= 45
/*****************************************************************************/
/* connect an object to a custom_data-record */

   RPIStub long
RPI_obj_connect_custom_data
   (RPI_HANDLE handle,RPI_OBJECT obj,char *custom_data_id,void *custom_data);

   /* handle:           refgateway-handle
      obj:              object-handle
      custom_data_id:   string, which is an identifier for the custom_data
      custom_data:      pointer to the custom_data
      returns:          0 if failed
                        1 if success
   */
/*****************************************************************************/
/* disconnect an object from a custom_data-record */

   RPIStub long
RPI_obj_disconnect_custom_data
   (RPI_HANDLE handle,RPI_OBJECT obj,char *custom_data_id);

   /* handle:           refgateway-handle
      obj:              object-handle
      custom_data_id:   string, which is an identifier for the custom_data
      returns:          0 if failed
                        1 if success
   */
/*****************************************************************************/
/* ask for the custom_data of an object */

   RPIStub long
RPI_obj_get_custom_data
   (RPI_HANDLE handle,RPI_OBJECT obj,char *custom_data_id,void **custom_data);

   /* handle:           refgateway-handle
      obj:              object-handle
      custom_data_id:   string, which is an identifier for the custom_data
      returns:          0 if failed
                        1 if success
   */
/*****************************************************************************/
/* add a loader/saver for a custom_data_id */

   RPIStub long
RPI_add_custom_data_load_save
   (RPI_HANDLE handle,char *custom_data_id);

   /* handle:           refgateway-handle
      custom_data_id:   string, which is an identifier for the custom_data
      returns:          0 if failed
                        1 if success
   */
/*****************************************************************************/
/* sub a loader/saver for a custom_data_id */

   RPIStub long
RPI_sub_custom_data_load_save
   (RPI_HANDLE handle,char *custom_data_id);

   /* handle:           refgateway-handle
      custom_data_id    string, which is an identifier for the custom_data
      returns:          0 if failed
                        1 if success
   */
/*****************************************************************************/
#endif /* MONZOOM_VERSION >= 45 */
/*****************************************************************************/
