/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/
/* title:    pkl functions */
/* author:   Carsten Fuchs */
/* version:  1.0, 16.9.97 */
/* updated:  21.9.98 */
/* version:  1.1, 16.9.98 */
/* updated:  17.11.99 */
/* updated:  2.3.2000 by RG */
/*****************************************************************************/
/* plot all objects in the pkl in all reflections displays */

   RPIStub long
RPI_plot_pkl
   (RPI_HANDLE handle);

   /* handle:       refgateway-handle
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* plot from a triangle-object a number of triangles in one specific display
   or in all reflections displays.
   this function works only for displays which are in wire-frame-modus
*/

   RPIStub long
RPI_plot_triangles
   (RPI_HANDLE handle,RPI_OBJECT drei,long ndrei,long drei_mode,long *dreiecke,long display_id,long hidd_mode,long color);

   /* handle:       refgateway-handle
      drei:         the triangles object whose the triangles are to be plotted
                    (must(!) be in the pkl)
      ndrei:        nr of triangles to be plotted
      drei_mode:    flag, wether in dreiecke are <ndrei>*3 numbers of vertices of <ndrei> triangles (drei_mode=0)
                    or <ndrei> numbers of triangles (drei_mode=1)
      dreiecke:     the numbers of the vertices of the triangles. 3 numbers for each triangle (drei_mode=0)
                    or the numbers of the triangles (drei_mode=1)
      display_id:   the number of the display, in which the triangles have to be plotted.
                    if display_id==0, they will be plotted in all displays, which are in
                    wire-frame-modus.
      hidd_mode:    the hidden-modus determing how the triangles have to be plotted:
                    (like the hidden-modi of the display-manager 0..2)
      color:        a color-number to plot the triangles.
                    PLOT_COLOR_BACKGROUND .. PLOT_COLOR_BLACK
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* add an object to the pkl */

   RPIStub long
RPI_pkl_add
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:       refgateway-handle
      obj:          object-handle of object to add to the pkl
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* remove an object from the pkl */

   RPIStub long
RPI_pkl_sub
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:       refgateway-handle
      obj:          object-handle of object to remove from the pkl
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* center all displays to show the given object */

   RPIStub long
RPI_pkl_center_obj
   (RPI_HANDLE handle,RPI_OBJECT obj);

   /* handle:          refgateway-handle
      obj:             object-handle
      returns:         0 if failed
                       1 if success
   */
/*****************************************************************************/
/* ask if an object is in the PKL */

   RPIStub long
RPI_obj_in_pkl
   (RPI_HANDLE handle,RPI_OBJECT obj,long *is_in_pkl);

   /* handle:       refgateway-handle
      obj:          object-handle
      is_in_pkl:    destination for flag if obj is in pkl
                    0 = no
                    1 = yes
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* ask how many objects are in the PKL */

   RPIStub long
RPI_n_pkl_objs
   (RPI_HANDLE handle,long *n_pkl_objs);

   /* handle:       refgateway-handle
      n_pkl_objs:   destination for number of pkl-objs
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get the objects of the PKL */

   RPIStub long
RPI_get_pkl_objs
   (RPI_HANDLE handle,RPI_OBJECT *obj_array,long max_array,long *n_pkl);

   /* handle:       refgateway-handle
      obj_array:    array to copy the handles of the pkl-objs
      max_array:    maximum number of objects to copy to the obj_array
      *n_pkl:       number of objects actually copied to obj_array
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* define a new configuration of displays and plot all objects in the pkl */

   RPIStub long
RPI_set_ansicht
   (RPI_HANDLE handle,long nr);

   /* handle:       refgateway-handle
      nr:           nr of display-configuration
                    0=front, 1=back, 2=left, 3=right,
                    4=bottom, 5=top, 6=perspective view, 7=4 views
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get the actual configuration of displays */

   RPIStub long
RPI_get_ansicht
   (RPI_HANDLE handle,long *nr);

   /* handle:       refgateway-handle
      nr:           destination for nr of display-configuration
                    0=front, 1=back, 2=left, 3=right,
                    4=bottom, 5=top, 6=perspective view, 7=4 views ,
                    8=reserved (for future-use)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* get the actual settings for skala */

   RPIStub long
RPI_get_skala
   (RPI_HANDLE handle,long *skala,float *label_x,float *label_y);

   /* handle:       refgateway-handle
      skala:        destination a flag, wether skala is on (1) or off(0)
      label_x:      destination for the <abstand> of x-labels
      label_y:      destination for the <abstand> of y-labels
                    (label_x/y are only valid if the skala is on)
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
/* set the actual settings for skala */

   RPIStub long
RPI_set_skala
   (RPI_HANDLE handle,long skala,long user_labels,float label_x);

   /* handle:       refgateway-handle
      skala:        flag, wether to switch the skala on(1) or off(0)
      user_labels:  flag, wether the label<abstand> should be used from label_x
      label_x:      if user_labels is on, then label_x is the desired label-<abstand>
      returns:      0 if failed
                    1 if ok
   */
/*****************************************************************************/
