/*****************************************************************************/
/*          refgateway stub functions for proper and save usage              */
/*                  of the RPI_do(in,out) commands.                          */
/*****************************************************************************/

/* title:    particles functions */
/* author:   Reinhard Grams */
/* version:  1.0, 24.9.97 */
/* updated:  23.3.98 by RG */
/* updated:  17.11.99 by RG */
/* updated:  2.3.2000 by RG */

/*****************************************************************************/
/* set the color of a particle */

   RPIStub long
RPI_prt_set_color
   (RPI_HANDLE handle,RPI_OBJECT obj,long partnr,float rgb[3])
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      partnr:       index number of particle (point)
      rgb:          new color of particle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long i;

   in.v_param[0]=handle;
   in.id=RPI_PRT_SET_COL;
   in.v_param[1]=obj;
   in.l_param[0]=partnr;
   for (i=0;i<3;i++)
      in.f_param[i]=rgb[i];
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the color of a particle */

   RPIStub long
RPI_prt_get_color
   (RPI_HANDLE handle,RPI_OBJECT obj,long partnr,float rgb[3])
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      partnr:       index number of particle (point)
      rgb:          destination for color of particle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret,i;

   in.v_param[0]=handle;
   in.id=RPI_PRT_GET_COL;
   in.v_param[1]=obj;
   in.l_param[0]=partnr;
   if (0!=(ret=RPI_do(&in,&out))) {
      for (i=0;i<3;i++)
         rgb[i]=out.f_param[i];
   }
   return(ret);
}
/*****************************************************************************/
/* set the influence and size of a particle */

   RPIStub long
RPI_prt_set_size
   (RPI_HANDLE handle,RPI_OBJECT obj,long partnr,float influence,float size)
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      partnr:       index number of particle (point)
      influence:    new influence factor for particle
      size:         new size for particle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_PRT_SET_SIZE;
   in.v_param[1]=obj;
   in.l_param[0]=partnr;
   in.f_param[0]=influence;
   in.f_param[1]=size;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the influence and size of a particle */

   RPIStub long
RPI_prt_get_size
   (RPI_HANDLE handle,RPI_OBJECT obj,long partnr,float *influence,float *size)
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      partnr:       index number of particle (point)
      influence:    destination for influence factor of particle
      size:         destination for size of particle
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_PRT_GET_SIZE;
   in.v_param[1]=obj;
   in.l_param[0]=partnr;
   if (0!=(ret=RPI_do(&in,&out))) {
      *influence=out.f_param[0];
      *size=out.f_param[1];
   }
   return(ret);
}
/*****************************************************************************/
/* set the number of user parameters for a particle, 0..32 */

   RPIStub long
RPI_prt_set_nparam
   (RPI_HANDLE handle,RPI_OBJECT obj,long nparam)
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      nparam:       number of user params for the particles of this object
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_PRT_SET_NPARAM;
   in.v_param[1]=obj;
   in.l_param[0]=nparam;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the number of user parameters for a particle, 0..32 */

   RPIStub long
RPI_prt_get_nparam
   (RPI_HANDLE handle,RPI_OBJECT obj,long *nparam)
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      nparam:       destination for number of user params for the
                    particles of this object
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_PRT_GET_NPARAM;
   in.v_param[1]=obj;
   if (0!=(ret=RPI_do(&in,&out)))
      *nparam=out.l_param[0];
   return(ret);
}
/*****************************************************************************/
/* set the value of an user parameter with index 0..31 */

   RPIStub long
RPI_prt_set_data
   (RPI_HANDLE handle,RPI_OBJECT obj,long partnr,long parmnr,float value)
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      partnr:       index number of the particle (point)
      parmnr:       index number of the parameter (0..31)
      value:        the new value for param[parmnr]
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;

   in.v_param[0]=handle;
   in.id=RPI_PRT_SET_DATA;
   in.v_param[1]=obj;
   in.l_param[0]=partnr;
   in.l_param[1]=parmnr;
   in.f_param[0]=value;
   return(RPI_do(&in,&out));
}
/*****************************************************************************/
/* get the value of an user parameter with index 0..31 */

   RPIStub long
RPI_prt_get_data
   (RPI_HANDLE handle,RPI_OBJECT obj,long partnr,long parmnr,float *value)
{
   /* handle:       refgateway-handle
      obj:          particle object-handle
      partnr:       index number of the particle (point)
      parmnr:       index number of the parameter (0..31)
      value:        destination for the value of param[parmnr]
      returns:      0 if failed
                    1 if ok
   */
   PLI_param in,out;
   long ret;

   in.v_param[0]=handle;
   in.id=RPI_PRT_GET_DATA;
   in.v_param[1]=obj;
   in.l_param[0]=partnr;
   in.l_param[1]=parmnr;
   if (0!=(ret=RPI_do(&in,&out)))
      *value=out.f_param[0];
   return(ret);
}
/*****************************************************************************/
