/*****************************************************************************/
/*          refgateway stubs definitions for proper and save usage           */
/*                      of the RPI_do(in,out) commands.                      */
/*****************************************************************************/

/* title:    refgateway stubs definitions */
/* author:   Reinhard Grams  */
/* version:  1.0, 17.9.97   */
/* updated:  27.3.98 by RG */
/* updated:  19.11.99 by RG */
/* updated:  14.1.2000 by RG */
/* updated:  2.3.2000 by RG */

/*****************************************************************************/

#ifndef STUB_DEFS_INCLUDED
#define STUB_DEFS_INCLUDED

/*****************************************************************************/
/* get version for MonPlugs.dll */

#ifdef PLUGIN_STUBS_LIBRARY
   #ifdef __cplusplus
      #define RPIStub extern "C"
   #else
      #define RPIStub __declspec (dllimport)
   #endif
RPIStub unsigned long MonPlugsGetVersion(void);
#endif

/*****************************************************************************/
/* if not defined, define as empty */

#ifndef RPIStub
#define RPIStub
#endif 

/*****************************************************************************/
/* this handles can only be passed to stub functions, other use is forbidden */
/* do not depend on the type of the ptr! it may be changed without notice! */

typedef void* RPI_HANDLE;        /* the handle of the plugin */
typedef void* RPI_OBJECT;        /* handle for an object */
typedef void* RPI_FILE_HANDLE;   /* file handle used by RPI_do */
typedef void* RPI_HEAP;          /* memory heap */

struct _rpi_file_ { /* this is private! */

   RPI_HANDLE        handle;
   RPI_FILE_HANDLE   file;
   long              mode;
};

typedef struct _rpi_file_* RPI_FILE;   /* file handle used by stub functions */

#define FILE_STR_DELIMITER (char)0xA
#define FILE_CAR_RETURN    (char)0xD
#define FILE_SPACE_CHR     (char)0x20

/*****************************************************************************/
/* flags for the byte order of a file */

#define FILE_TYPE_IGNORE   0
#define FILE_TYPE_MOTOROLA 1
#define FILE_TYPE_INTEL    2

/*****************************************************************************/
/* valid return values of a plugin message handler */

#define RPI_MESSAGE_PROCESSED  1
#define RPI_MESSAGE_UNKNOWN    0
#define RPI_MESSAGE_ERROR     -1

/*****************************************************************************/
/* return values of tools in out->l_param[0], obsolete! */

#define TOOL_ERROR   0
#define TOOL_OK      1

/*****************************************************************************/
/* return values of a loader plugin in out->l_param[0] */

#define LOAD_SCENE_UNKNOWN    0
#define LOAD_SCENE_PROCESSED  1
#define LOAD_SCENE_ERROR      2

/*****************************************************************************/
/* reflection object ids (types) */

#define OBJEKT_ID                            1
#define GEO_OBJEKT_ID                        2
#define DREIECKS_OBJEKT_ID                   3
#define GRUNDMATERIAL_OBJEKT_ID              4
#define POLYGON_3D_OBJEKT_ID                 5
#define POLYGON_2D_OBJEKT_ID                 6
#define OBERFLAECHENMATERIAL_OBJEKT_ID       7
#define KOERPER_OBJEKT_ID                    8
#define SEQUENZ_OBJEKT_ID                    9
#define KAMERA_OBJEKT_ID                     10
#define BEZIER_OBJEKT_ID                     11
#define LICHT_OBJEKT_ID                      12
#define TEXTURMATERIAL_OBJEKT_ID             14
#define TEXTUR_OBJEKT_ID                     15
#define GITTER_3D_OBJEKT_ID                  16
#define NEBELMATERIAL_OBJEKT_ID              17
#define SHARED_POINTS_OBJEKT_ID              19
#define ANIM_TEXTURMATERIAL_OBJEKT_ID        20
#define SHARED_POINTS_FUNKTION_OBJEKT_ID     21
#define KUGEL_OBJEKT_ID                      22
#define GLUEH_MATERIAL_OBJEKT_ID             23
#define SKELETT_OBJEKT_ID                    24
#define VERTEILTE_LICHTQUELLE_OBJEKT_ID      26
#define PARTIKEL_OBJEKT_ID                   27
#define MATHE_TEXTUR_OBJEKT_ID               28
#define VOLUMEN_LICHT_OBJEKT_ID              30
#define KANTEN_GEO_OBJEKT_ID                 31
#define KOMBI_MATERIAL_OBJEKT_ID             32
#define KLONE_DREIECKS_OBJEKT_ID             33
#define AKTIONS_SEQUENZ_OBJEKT_ID            34

/*****************************************************************************/
/* defines for auto load of data */

#ifdef PLUGIN_STANDARD_CONFIG_HANDLING

typedef struct { short type,count; } DataDesc; 

#define DATA_TYPES   4
#define DATA_STRING  0
#define DATA_FLOAT   1
#define DATA_LONG    2
#define DATA_SHORT   3
  
typedef struct {

   long (*functions[DATA_TYPES])(RPI_FILE,void *,long);

} DataIO;

// von Rge_stub.c:
extern long data_size[DATA_TYPES];
extern DataIO data_read;
extern DataIO data_write;

#endif

/*****************************************************************************/
/* reflections color order */

#define RED    0
#define GREEN  1
#define BLUE   2

/*****************************************************************************/
/* reflections smooth flag */

#define REF_FLAT_FLAG      0
#define REF_SMOOTH_FLAG    1

/*****************************************************************************/
/* flags for alphabetic sorting in the string requesters */

#define REF_DO_NOT_SORT_ENTRIES     0
#define REF_SORT_ENTRIES            1

/*****************************************************************************/
/* flags for RPI_get_objs and RPI_n_objs */

#define EXCLUDE_SUBCLASSES    0
#define INCLUDE_SUBCLASSES    1

/*****************************************************************************/

#if MONZOOM_VERSION >= 45
/* changed in version 4.5 to 64 chars */
#define REFLECTIONS_NAME_BUFFER_SIZE 64
#else
/* in older versions the maximum length of a name is 32 chars */
#define REFLECTIONS_NAME_BUFFER_SIZE 32
#endif

/*****************************************************************************/


#endif

/*****************************************************************************/
