/*****************************************************************************/
// return values of functions

typedef long error;

#define SPLREQ_OK                   0
#define SPLREQ_DRAW_ERR             1
#define SPLREQ_GET_VALUE_ERR        2
#define SPLREQ_SET_FONT_ERR         3
#define SPLREQ_CLOSE_DISP_ERR       4
#define SPLREQ_OPEN_DISP_ERR        5
#define SPLREQ_OPEN_REQ_ERR         6
#define SPLREQ_CLOSE_DISPLAY_ERR    7
#define SPLREQ_INVALID_BUFFER_ERR   8

/*****************************************************************************/

// do not edit this constants
#define NR_OF_SPLINE_ENTRIES        (NR_OF_SPLINE_HANDLES+2)
#define SPLINE_NO_HANDLE_ACTIVE     -1
#define SPLINE_NO_WINDOW_OPEN       0
#define SPLINE_NR_OF_LABELS         5
#define SPLINE_TEXT_FRAME           2
#define SPLINE_LABEL_MAX_LENGHT     16
#define SPLINE_HANDLE_ENABLED       0
#define SPLINE_HANDLE_DISABLED      1

#define SPLINE_REFRESH_ON_RELEASE   0
#define SPLINE_REFRESH_ON_MOVE      1

#define SPLINE_INIT_MINIMUM         0
#define SPLINE_INIT_MAXIMUM         1
#define SPLINE_INIT_RAMP            2

typedef struct {

   float    *spline;
   float    *handles_x;
   float    *handles_y;
   float    *org_handles_x;
   float    *org_handles_y;
   float    *entries_x;
   float    *entries_y;
   char     *handle_status;
   long     nr_of_spline_points;
   long     nr_of_spline_handles;
   long     nr_of_spline_entries;
   long     spline_x_resolution;
   long     spline_y_resolution;
   long     handle_radius;
   long     spline_frame[3];
   long     spline_background[3];
   long     spline_points[3];
   long     spline_handles[3];
   long     spline_grid[3];
   long     spline_text_color[3];
   long     spline_text_background[3];
   long     requester_active;
   long     active_handle;
   long     window;
   long     text_space;
   char     labels[SPLINE_NR_OF_LABELS][SPLINE_LABEL_MAX_LENGHT];
   short    labels_width[SPLINE_NR_OF_LABELS];
   short    labels_height[SPLINE_NR_OF_LABELS];
   short    labels_start[SPLINE_NR_OF_LABELS];
   void     *HND;
   void     *heap;
   float    mix;
   long     data_allocated;
   long     handles_x_private;
   long     handles_y_private;

} SplineReq; 

/*****************************************************************************/

// handle is the handle of the calling plugin. heap may be NULL
// nr_of_handles must be at least 2, nr_of_points may be 0
#define SplineReqFunc extern "C"
   SplineReqFunc SplineReq *
SplineCreateData
   (long nr_of_handles,long nr_of_points,long req_width,long req_height,long handle_radius,void *handle,void *heap,long init_flag);

// removes data structure allocated with SplineCreateData
   SplineReqFunc void
SplineRemoveData
   (SplineReq *data);

// handle is the handle of the calling plugin
   SplineReqFunc error
SplineCreateRequester
   (SplineReq *spline,char *title,void *handle,float min_value,float max_value,char *label_format,long x,long y);

// close the requester
   SplineReqFunc void
SplineCloseRequester
   (SplineReq *spline);

// call this if you changed the values of the handles
   SplineReqFunc error
SplineUpdateRequester
   (SplineReq *spline);

// to be called when plugin recieves PLI_DISP_MOUSE_MOVE
   SplineReqFunc error
SplineHandleMouseEvent
   (SplineReq *spline,long display_id,long code,long button,long x,long y,long refresh_type,long *refresh);
// refresh_types are SPLINE_REFRESH_ON_RELEASE and SPLINE_REFRESH_ON_MOVE
// refresh is a flag set depending on refresh_type

// to be called when plugin recieves PLI_DISP_CLOSED
   SplineReqFunc void
SplineInformReqWindowClosed
   (SplineReq *spline);

// call this if you want to change the handles x-buffer
// call SplineUpdateRequester if requester is active 
   SplineReqFunc error
SplineSetHandlesBufferX
   (SplineReq *spline,float *buffer,long nr_of_handles);

// call this if you want to change the handles y-buffer
// call SplineUpdateRequester if requester is active 
   SplineReqFunc error
SplineSetHandlesBufferY
   (SplineReq *spline,float *buffer,long nr_of_handles);

// set the smoothin strength of the spline
// call SplineUpdateRequester if requester is active 
   SplineReqFunc void
SplineSetSmooth
   (SplineReq *spline,float smooth);

// Get the spline value at given x coordinate 0<=x<=1
// if you created the spline requester with spline_points>0
// you can take the values out of the spline_req->spline buffer
   SplineReqFunc float
SplineGetSplineValue
   (SplineReq *spline,float x);

// Get the current x value (position) of a handle
   SplineReqFunc float
SplineGetHandleValueX
   (SplineReq *spline,long handle_nr);

// Get the current y value (position) of a handle
   SplineReqFunc float
SplineGetHandleValueY
   (SplineReq *spline,long handle_nr);

// Set the x value (position) of a handle
// call SplineUpdateRequester after setting all handles if requester is active 
   SplineReqFunc void
SplineSetHandleValueX
   (SplineReq *spline,long handle_nr,float value);

// Set the y value (position) of a handle
// call SplineUpdateRequester after setting all handles if requester is active 
   SplineReqFunc void
SplineSetHandleValueY
   (SplineReq *spline,long handle_nr,float value);

// Set status of a handle, SPLINE_HANDLE_ENABLED or SPLINE_HANDLE_DISABLED
   SplineReqFunc void
SplineSetHandleStatus
   (SplineReq *spline,long handle_nr,char status);

/*****************************************************************************/
